/* Generated by re2c 1.3 */
#include <stdlib.h>
#include "chunk.h"
#include "scanners.h"

bufsize_t _scan_at(bufsize_t (*scanner)(const unsigned char *), cmark_chunk *c,
                   bufsize_t offset) {
  bufsize_t res;
  unsigned char *ptr = (unsigned char *)c->data;

  if (ptr == NULL || offset > c->len) {
    return 0;
  } else {
    unsigned char lim = ptr[c->len];

    ptr[c->len] = '\0';
    res = scanner(ptr + offset);
    ptr[c->len] = lim;
  }

  return res;
}

// Try to match a scheme including colon.
bufsize_t _scan_scheme(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    yych = *p;
    if (yych <= '@')
      goto yy2;
    if (yych <= 'Z')
      goto yy4;
    if (yych <= '`')
      goto yy2;
    if (yych <= 'z')
      goto yy4;
  yy2:
    ++p;
  yy3 : { return 0; }
  yy4:
    yych = *(marker = ++p);
    if (yych <= '/') {
      if (yych <= '+') {
        if (yych <= '*')
          goto yy3;
      } else {
        if (yych <= ',')
          goto yy3;
        if (yych >= '/')
          goto yy3;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '9')
          goto yy5;
        if (yych <= '@')
          goto yy3;
      } else {
        if (yych <= '`')
          goto yy3;
        if (yych >= '{')
          goto yy3;
      }
    }
  yy5:
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych == '+')
          goto yy7;
      } else {
        if (yych != '/')
          goto yy7;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych >= 'A')
          goto yy7;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych <= 'z')
          goto yy7;
      }
    }
  yy6:
    p = marker;
    goto yy3;
  yy7:
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych == '+')
          goto yy10;
        goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
        goto yy10;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
        goto yy10;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych <= 'z')
          goto yy10;
        goto yy6;
      }
    }
  yy8:
    ++p;
    { return (bufsize_t)(p - start); }
  yy10:
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy8;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych == ':')
      goto yy8;
    goto yy6;
  }
}

// Try to match URI autolink after first <, returning number of chars matched.
bufsize_t _scan_autolink_uri(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 0,   128, 0,   128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,
    };
    yych = *p;
    if (yych <= '@')
      goto yy41;
    if (yych <= 'Z')
      goto yy43;
    if (yych <= '`')
      goto yy41;
    if (yych <= 'z')
      goto yy43;
  yy41:
    ++p;
  yy42 : { return 0; }
  yy43:
    yych = *(marker = ++p);
    if (yych <= '/') {
      if (yych <= '+') {
        if (yych <= '*')
          goto yy42;
      } else {
        if (yych <= ',')
          goto yy42;
        if (yych >= '/')
          goto yy42;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '9')
          goto yy44;
        if (yych <= '@')
          goto yy42;
      } else {
        if (yych <= '`')
          goto yy42;
        if (yych >= '{')
          goto yy42;
      }
    }
  yy44:
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych == '+')
          goto yy46;
      } else {
        if (yych != '/')
          goto yy46;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych >= 'A')
          goto yy46;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych <= 'z')
          goto yy46;
      }
    }
  yy45:
    p = marker;
    goto yy42;
  yy46:
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych == '+')
          goto yy49;
        goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
        goto yy49;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
        goto yy49;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych <= 'z')
          goto yy49;
        goto yy45;
      }
    }
  yy47:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy47;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '<')
          goto yy45;
        if (yych <= '>')
          goto yy50;
        goto yy45;
      } else {
        if (yych <= 0xDF)
          goto yy52;
        if (yych <= 0xE0)
          goto yy53;
        goto yy54;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy55;
        if (yych <= 0xEF)
          goto yy54;
        goto yy56;
      } else {
        if (yych <= 0xF3)
          goto yy57;
        if (yych <= 0xF4)
          goto yy58;
        goto yy45;
      }
    }
  yy49:
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych == '+')
          goto yy59;
        goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
        goto yy59;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
        goto yy59;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych <= 'z')
          goto yy59;
        goto yy45;
      }
    }
  yy50:
    ++p;
    { return (bufsize_t)(p - start); }
  yy52:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy45;
    if (yych <= 0xBF)
      goto yy47;
    goto yy45;
  yy53:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy45;
    if (yych <= 0xBF)
      goto yy52;
    goto yy45;
  yy54:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy45;
    if (yych <= 0xBF)
      goto yy52;
    goto yy45;
  yy55:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy45;
    if (yych <= 0x9F)
      goto yy52;
    goto yy45;
  yy56:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy45;
    if (yych <= 0xBF)
      goto yy54;
    goto yy45;
  yy57:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy45;
    if (yych <= 0xBF)
      goto yy54;
    goto yy45;
  yy58:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy45;
    if (yych <= 0x8F)
      goto yy54;
    goto yy45;
  yy59:
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy47;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych == ':')
      goto yy47;
    goto yy45;
  }
}

// Try to match email autolink after first <, returning num of chars matched.
bufsize_t _scan_autolink_email(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   128, 0,   128, 128, 128, 128, 128, 0,   0,
        128, 128, 0,   128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 0,   0,   0,   128, 0,   128, 0,   128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 0,   0,   0,   128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,
    };
    yych = *p;
    if (yych <= '9') {
      if (yych <= '\'') {
        if (yych == '!')
          goto yy91;
        if (yych >= '#')
          goto yy91;
      } else {
        if (yych <= ')')
          goto yy89;
        if (yych != ',')
          goto yy91;
      }
    } else {
      if (yych <= '?') {
        if (yych == '=')
          goto yy91;
        if (yych >= '?')
          goto yy91;
      } else {
        if (yych <= 'Z') {
          if (yych >= 'A')
            goto yy91;
        } else {
          if (yych <= ']')
            goto yy89;
          if (yych <= '~')
            goto yy91;
        }
      }
    }
  yy89:
    ++p;
  yy90 : { return 0; }
  yy91:
    yych = *(marker = ++p);
    if (yych <= ',') {
      if (yych <= '"') {
        if (yych == '!')
          goto yy93;
        goto yy90;
      } else {
        if (yych <= '\'')
          goto yy93;
        if (yych <= ')')
          goto yy90;
        if (yych <= '+')
          goto yy93;
        goto yy90;
      }
    } else {
      if (yych <= '>') {
        if (yych <= '9')
          goto yy93;
        if (yych == '=')
          goto yy93;
        goto yy90;
      } else {
        if (yych <= 'Z')
          goto yy93;
        if (yych <= ']')
          goto yy90;
        if (yych <= '~')
          goto yy93;
        goto yy90;
      }
    }
  yy92:
    yych = *++p;
  yy93:
    if (yybm[0 + yych] & 128) {
      goto yy92;
    }
    if (yych <= '>')
      goto yy94;
    if (yych <= '@')
      goto yy95;
  yy94:
    p = marker;
    goto yy90;
  yy95:
    yych = *++p;
    if (yych <= '@') {
      if (yych <= '/')
        goto yy94;
      if (yych >= ':')
        goto yy94;
    } else {
      if (yych <= 'Z')
        goto yy96;
      if (yych <= '`')
        goto yy94;
      if (yych >= '{')
        goto yy94;
    }
  yy96:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy98;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy98;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy98;
        goto yy94;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy101;
      if (yych <= '/')
        goto yy94;
      goto yy102;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy102;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy102;
        goto yy94;
      }
    }
  yy98:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych <= '-')
          goto yy101;
        goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy102;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy102;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy102;
        goto yy94;
      }
    }
  yy99:
    ++p;
    { return (bufsize_t)(p - start); }
  yy101:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy103;
      if (yych <= '/')
        goto yy94;
      goto yy104;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy104;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy104;
        goto yy94;
      }
    }
  yy102:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy104;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy104;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy104;
        goto yy94;
      }
    }
  yy103:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy105;
      if (yych <= '/')
        goto yy94;
      goto yy106;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy106;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy106;
        goto yy94;
      }
    }
  yy104:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy106;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy106;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy106;
        goto yy94;
      }
    }
  yy105:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy107;
      if (yych <= '/')
        goto yy94;
      goto yy108;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy108;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy108;
        goto yy94;
      }
    }
  yy106:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy108;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy108;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy108;
        goto yy94;
      }
    }
  yy107:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy109;
      if (yych <= '/')
        goto yy94;
      goto yy110;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy110;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy110;
        goto yy94;
      }
    }
  yy108:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy110;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy110;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy110;
        goto yy94;
      }
    }
  yy109:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy111;
      if (yych <= '/')
        goto yy94;
      goto yy112;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy112;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy112;
        goto yy94;
      }
    }
  yy110:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy112;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy112;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy112;
        goto yy94;
      }
    }
  yy111:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy113;
      if (yych <= '/')
        goto yy94;
      goto yy114;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy114;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy114;
        goto yy94;
      }
    }
  yy112:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy114;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy114;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy114;
        goto yy94;
      }
    }
  yy113:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy115;
      if (yych <= '/')
        goto yy94;
      goto yy116;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy116;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy116;
        goto yy94;
      }
    }
  yy114:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy116;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy116;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy116;
        goto yy94;
      }
    }
  yy115:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy117;
      if (yych <= '/')
        goto yy94;
      goto yy118;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy118;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy118;
        goto yy94;
      }
    }
  yy116:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy118;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy118;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy118;
        goto yy94;
      }
    }
  yy117:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy119;
      if (yych <= '/')
        goto yy94;
      goto yy120;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy120;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy120;
        goto yy94;
      }
    }
  yy118:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy120;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy120;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy120;
        goto yy94;
      }
    }
  yy119:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy121;
      if (yych <= '/')
        goto yy94;
      goto yy122;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy122;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy122;
        goto yy94;
      }
    }
  yy120:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy122;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy122;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy122;
        goto yy94;
      }
    }
  yy121:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy123;
      if (yych <= '/')
        goto yy94;
      goto yy124;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy124;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy124;
        goto yy94;
      }
    }
  yy122:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy124;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy124;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy124;
        goto yy94;
      }
    }
  yy123:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy125;
      if (yych <= '/')
        goto yy94;
      goto yy126;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy126;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy126;
        goto yy94;
      }
    }
  yy124:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy126;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy126;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy126;
        goto yy94;
      }
    }
  yy125:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy127;
      if (yych <= '/')
        goto yy94;
      goto yy128;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy128;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy128;
        goto yy94;
      }
    }
  yy126:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy128;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy128;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy128;
        goto yy94;
      }
    }
  yy127:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy129;
      if (yych <= '/')
        goto yy94;
      goto yy130;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy130;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy130;
        goto yy94;
      }
    }
  yy128:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy130;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy130;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy130;
        goto yy94;
      }
    }
  yy129:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy131;
      if (yych <= '/')
        goto yy94;
      goto yy132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy132;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy132;
        goto yy94;
      }
    }
  yy130:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy132;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy132;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy132;
        goto yy94;
      }
    }
  yy131:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy133;
      if (yych <= '/')
        goto yy94;
      goto yy134;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy134;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy134;
        goto yy94;
      }
    }
  yy132:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy134;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy134;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy134;
        goto yy94;
      }
    }
  yy133:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy135;
      if (yych <= '/')
        goto yy94;
      goto yy136;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy136;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy136;
        goto yy94;
      }
    }
  yy134:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy136;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy136;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy136;
        goto yy94;
      }
    }
  yy135:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy137;
      if (yych <= '/')
        goto yy94;
      goto yy138;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy138;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy138;
        goto yy94;
      }
    }
  yy136:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy138;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy138;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy138;
        goto yy94;
      }
    }
  yy137:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy139;
      if (yych <= '/')
        goto yy94;
      goto yy140;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy140;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy140;
        goto yy94;
      }
    }
  yy138:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy140;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy140;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy140;
        goto yy94;
      }
    }
  yy139:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy141;
      if (yych <= '/')
        goto yy94;
      goto yy142;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy142;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy142;
        goto yy94;
      }
    }
  yy140:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy142;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy142;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy142;
        goto yy94;
      }
    }
  yy141:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy143;
      if (yych <= '/')
        goto yy94;
      goto yy144;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy144;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy144;
        goto yy94;
      }
    }
  yy142:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy144;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy144;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy144;
        goto yy94;
      }
    }
  yy143:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy145;
      if (yych <= '/')
        goto yy94;
      goto yy146;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy146;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy146;
        goto yy94;
      }
    }
  yy144:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy146;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy146;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy146;
        goto yy94;
      }
    }
  yy145:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy147;
      if (yych <= '/')
        goto yy94;
      goto yy148;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy148;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy148;
        goto yy94;
      }
    }
  yy146:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy148;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy148;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy148;
        goto yy94;
      }
    }
  yy147:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy149;
      if (yych <= '/')
        goto yy94;
      goto yy150;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy150;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy150;
        goto yy94;
      }
    }
  yy148:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy150;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy150;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy150;
        goto yy94;
      }
    }
  yy149:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy151;
      if (yych <= '/')
        goto yy94;
      goto yy152;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy152;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy152;
        goto yy94;
      }
    }
  yy150:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy152;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy152;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy152;
        goto yy94;
      }
    }
  yy151:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy153;
      if (yych <= '/')
        goto yy94;
      goto yy154;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy154;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy154;
        goto yy94;
      }
    }
  yy152:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy154;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy154;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy154;
        goto yy94;
      }
    }
  yy153:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy155;
      if (yych <= '/')
        goto yy94;
      goto yy156;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy156;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy156;
        goto yy94;
      }
    }
  yy154:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy156;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy156;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy156;
        goto yy94;
      }
    }
  yy155:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy157;
      if (yych <= '/')
        goto yy94;
      goto yy158;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy158;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy158;
        goto yy94;
      }
    }
  yy156:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy158;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy158;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy158;
        goto yy94;
      }
    }
  yy157:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy159;
      if (yych <= '/')
        goto yy94;
      goto yy160;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy160;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy160;
        goto yy94;
      }
    }
  yy158:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy160;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy160;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy160;
        goto yy94;
      }
    }
  yy159:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy161;
      if (yych <= '/')
        goto yy94;
      goto yy162;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy162;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy162;
        goto yy94;
      }
    }
  yy160:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy162;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy162;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy162;
        goto yy94;
      }
    }
  yy161:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy163;
      if (yych <= '/')
        goto yy94;
      goto yy164;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy164;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy164;
        goto yy94;
      }
    }
  yy162:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy164;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy164;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy164;
        goto yy94;
      }
    }
  yy163:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy165;
      if (yych <= '/')
        goto yy94;
      goto yy166;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy166;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy166;
        goto yy94;
      }
    }
  yy164:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy166;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy166;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy166;
        goto yy94;
      }
    }
  yy165:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy167;
      if (yych <= '/')
        goto yy94;
      goto yy168;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy168;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy168;
        goto yy94;
      }
    }
  yy166:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy168;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy168;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy168;
        goto yy94;
      }
    }
  yy167:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy169;
      if (yych <= '/')
        goto yy94;
      goto yy170;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy170;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy170;
        goto yy94;
      }
    }
  yy168:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy170;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy170;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy170;
        goto yy94;
      }
    }
  yy169:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy171;
      if (yych <= '/')
        goto yy94;
      goto yy172;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy172;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy172;
        goto yy94;
      }
    }
  yy170:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy172;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy172;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy172;
        goto yy94;
      }
    }
  yy171:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy173;
      if (yych <= '/')
        goto yy94;
      goto yy174;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy174;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy174;
        goto yy94;
      }
    }
  yy172:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy174;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy174;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy174;
        goto yy94;
      }
    }
  yy173:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy175;
      if (yych <= '/')
        goto yy94;
      goto yy176;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy176;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy176;
        goto yy94;
      }
    }
  yy174:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy176;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy176;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy176;
        goto yy94;
      }
    }
  yy175:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy177;
      if (yych <= '/')
        goto yy94;
      goto yy178;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy178;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy178;
        goto yy94;
      }
    }
  yy176:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy178;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy178;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy178;
        goto yy94;
      }
    }
  yy177:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy179;
      if (yych <= '/')
        goto yy94;
      goto yy180;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy180;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy180;
        goto yy94;
      }
    }
  yy178:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy180;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy180;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy180;
        goto yy94;
      }
    }
  yy179:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy181;
      if (yych <= '/')
        goto yy94;
      goto yy182;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy182;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy182;
        goto yy94;
      }
    }
  yy180:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy182;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy182;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy182;
        goto yy94;
      }
    }
  yy181:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy183;
      if (yych <= '/')
        goto yy94;
      goto yy184;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy184;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy184;
        goto yy94;
      }
    }
  yy182:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy184;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy184;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy184;
        goto yy94;
      }
    }
  yy183:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy185;
      if (yych <= '/')
        goto yy94;
      goto yy186;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy186;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy186;
        goto yy94;
      }
    }
  yy184:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy186;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy186;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy186;
        goto yy94;
      }
    }
  yy185:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy187;
      if (yych <= '/')
        goto yy94;
      goto yy188;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy188;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy188;
        goto yy94;
      }
    }
  yy186:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy188;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy188;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy188;
        goto yy94;
      }
    }
  yy187:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy189;
      if (yych <= '/')
        goto yy94;
      goto yy190;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy190;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy190;
        goto yy94;
      }
    }
  yy188:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy190;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy190;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy190;
        goto yy94;
      }
    }
  yy189:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy191;
      if (yych <= '/')
        goto yy94;
      goto yy192;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy192;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy192;
        goto yy94;
      }
    }
  yy190:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy192;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy192;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy192;
        goto yy94;
      }
    }
  yy191:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy193;
      if (yych <= '/')
        goto yy94;
      goto yy194;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy194;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy194;
        goto yy94;
      }
    }
  yy192:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy194;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy194;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy194;
        goto yy94;
      }
    }
  yy193:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy195;
      if (yych <= '/')
        goto yy94;
      goto yy196;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy196;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy196;
        goto yy94;
      }
    }
  yy194:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy196;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy196;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy196;
        goto yy94;
      }
    }
  yy195:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy197;
      if (yych <= '/')
        goto yy94;
      goto yy198;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy198;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy198;
        goto yy94;
      }
    }
  yy196:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy198;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy198;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy198;
        goto yy94;
      }
    }
  yy197:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy199;
      if (yych <= '/')
        goto yy94;
      goto yy200;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy200;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy200;
        goto yy94;
      }
    }
  yy198:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy200;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy200;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy200;
        goto yy94;
      }
    }
  yy199:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy201;
      if (yych <= '/')
        goto yy94;
      goto yy202;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy202;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy202;
        goto yy94;
      }
    }
  yy200:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy202;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy202;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy202;
        goto yy94;
      }
    }
  yy201:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy203;
      if (yych <= '/')
        goto yy94;
      goto yy204;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy204;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy204;
        goto yy94;
      }
    }
  yy202:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy204;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy204;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy204;
        goto yy94;
      }
    }
  yy203:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy205;
      if (yych <= '/')
        goto yy94;
      goto yy206;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy206;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy206;
        goto yy94;
      }
    }
  yy204:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy206;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy206;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy206;
        goto yy94;
      }
    }
  yy205:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy207;
      if (yych <= '/')
        goto yy94;
      goto yy208;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy208;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy208;
        goto yy94;
      }
    }
  yy206:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy208;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy208;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy208;
        goto yy94;
      }
    }
  yy207:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy209;
      if (yych <= '/')
        goto yy94;
      goto yy210;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy210;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy210;
        goto yy94;
      }
    }
  yy208:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy210;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy210;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy210;
        goto yy94;
      }
    }
  yy209:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy211;
      if (yych <= '/')
        goto yy94;
      goto yy212;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy212;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy212;
        goto yy94;
      }
    }
  yy210:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy212;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy212;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy212;
        goto yy94;
      }
    }
  yy211:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy213;
      if (yych <= '/')
        goto yy94;
      goto yy214;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy214;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy214;
        goto yy94;
      }
    }
  yy212:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy214;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy214;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy214;
        goto yy94;
      }
    }
  yy213:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy215;
      if (yych <= '/')
        goto yy94;
      goto yy216;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy216;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy216;
        goto yy94;
      }
    }
  yy214:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy216;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy216;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy216;
        goto yy94;
      }
    }
  yy215:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy217;
      if (yych <= '/')
        goto yy94;
      goto yy218;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy218;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy218;
        goto yy94;
      }
    }
  yy216:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy218;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy218;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy218;
        goto yy94;
      }
    }
  yy217:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy219;
      if (yych <= '/')
        goto yy94;
      goto yy220;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy94;
        goto yy220;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy220;
        goto yy94;
      }
    }
  yy218:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy94;
        if (yych >= '.')
          goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych <= '9')
          goto yy220;
        goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
        goto yy220;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych <= 'z')
          goto yy220;
        goto yy94;
      }
    }
  yy219:
    yych = *++p;
    if (yych <= '@') {
      if (yych <= '/')
        goto yy94;
      if (yych <= '9')
        goto yy221;
      goto yy94;
    } else {
      if (yych <= 'Z')
        goto yy221;
      if (yych <= '`')
        goto yy94;
      if (yych <= 'z')
        goto yy221;
      goto yy94;
    }
  yy220:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= '-')
          goto yy94;
        goto yy95;
      } else {
        if (yych <= '/')
          goto yy94;
        if (yych >= ':')
          goto yy94;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy99;
        if (yych <= '@')
          goto yy94;
      } else {
        if (yych <= '`')
          goto yy94;
        if (yych >= '{')
          goto yy94;
      }
    }
  yy221:
    yych = *++p;
    if (yych == '.')
      goto yy95;
    if (yych == '>')
      goto yy99;
    goto yy94;
  }
}

// Try to match an HTML tag after first <, returning num of chars matched.
bufsize_t _scan_html_tag(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        /* table 1 .. 8: 0 */
        0,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        235,
        235,
        235,
        235,
        235,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        250,
        235,
        250,
        202,
        250,
        250,
        250,
        250,
        170,
        250,
        250,
        250,
        250,
        250,
        246,
        254,
        250,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        250,
        234,
        234,
        232,
        250,
        250,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        250,
        250,
        122,
        250,
        254,
        234,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        254,
        250,
        250,
        250,
        250,
        250,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        /* table 9 .. 11: 256 */
        0,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        128,
        192,
        128,
        128,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        128,
        128,
        128,
        128,
        128,
        0,
        128,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        224,
        128,
        128,
        128,
        128,
        128,
        128,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        192,
        128,
        128,
        128,
        128,
        128,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
        0,
    };
    yych = *p;
    if (yych <= '>') {
      if (yych <= '!') {
        if (yych >= '!')
          goto yy226;
      } else {
        if (yych == '/')
          goto yy227;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '?')
          goto yy228;
        if (yych >= 'A')
          goto yy229;
      } else {
        if (yych <= '`')
          goto yy224;
        if (yych <= 'z')
          goto yy229;
      }
    }
  yy224:
    ++p;
  yy225 : { return 0; }
  yy226:
    yych = *(marker = ++p);
    if (yybm[256 + yych] & 32) {
      goto yy232;
    }
    if (yych == '-')
      goto yy230;
    if (yych <= '@')
      goto yy225;
    if (yych <= '[')
      goto yy234;
    goto yy225;
  yy227:
    yych = *(marker = ++p);
    if (yych <= '@')
      goto yy225;
    if (yych <= 'Z')
      goto yy235;
    if (yych <= '`')
      goto yy225;
    if (yych <= 'z')
      goto yy235;
    goto yy225;
  yy228:
    yych = *(marker = ++p);
    if (yych <= 0x00)
      goto yy225;
    if (yych <= 0x7F)
      goto yy238;
    if (yych <= 0xC1)
      goto yy225;
    if (yych <= 0xF4)
      goto yy238;
    goto yy225;
  yy229:
    yych = *(marker = ++p);
    if (yych <= '.') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy225;
        if (yych <= '\r')
          goto yy250;
        goto yy225;
      } else {
        if (yych <= ' ')
          goto yy250;
        if (yych == '-')
          goto yy250;
        goto yy225;
      }
    } else {
      if (yych <= '@') {
        if (yych <= '9')
          goto yy250;
        if (yych == '>')
          goto yy250;
        goto yy225;
      } else {
        if (yych <= 'Z')
          goto yy250;
        if (yych <= '`')
          goto yy225;
        if (yych <= 'z')
          goto yy250;
        goto yy225;
      }
    }
  yy230:
    yych = *++p;
    if (yych == '-')
      goto yy254;
  yy231:
    p = marker;
    goto yy225;
  yy232:
    yych = *++p;
    if (yybm[256 + yych] & 32) {
      goto yy232;
    }
    if (yych <= 0x08)
      goto yy231;
    if (yych <= '\r')
      goto yy255;
    if (yych == ' ')
      goto yy255;
    goto yy231;
  yy234:
    yych = *++p;
    if (yych == 'C')
      goto yy257;
    if (yych == 'c')
      goto yy257;
    goto yy231;
  yy235:
    yych = *++p;
    if (yybm[256 + yych] & 64) {
      goto yy235;
    }
    if (yych <= 0x1F) {
      if (yych <= 0x08)
        goto yy231;
      if (yych <= '\r')
        goto yy258;
      goto yy231;
    } else {
      if (yych <= ' ')
        goto yy258;
      if (yych == '>')
        goto yy252;
      goto yy231;
    }
  yy237:
    yych = *++p;
  yy238:
    if (yybm[256 + yych] & 128) {
      goto yy237;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy231;
        if (yych >= '@')
          goto yy231;
      } else {
        if (yych <= 0xDF)
          goto yy240;
        if (yych <= 0xE0)
          goto yy241;
        goto yy242;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy243;
        if (yych <= 0xEF)
          goto yy242;
        goto yy244;
      } else {
        if (yych <= 0xF3)
          goto yy245;
        if (yych <= 0xF4)
          goto yy246;
        goto yy231;
      }
    }
    yych = *++p;
    if (yych <= 0xE0) {
      if (yych <= '>') {
        if (yych <= 0x00)
          goto yy231;
        if (yych <= '=')
          goto yy237;
        goto yy252;
      } else {
        if (yych <= 0x7F)
          goto yy237;
        if (yych <= 0xC1)
          goto yy231;
        if (yych >= 0xE0)
          goto yy241;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy243;
        goto yy242;
      } else {
        if (yych <= 0xF0)
          goto yy244;
        if (yych <= 0xF3)
          goto yy245;
        if (yych <= 0xF4)
          goto yy246;
        goto yy231;
      }
    }
  yy240:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy237;
    goto yy231;
  yy241:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy240;
    goto yy231;
  yy242:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy240;
    goto yy231;
  yy243:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x9F)
      goto yy240;
    goto yy231;
  yy244:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy242;
    goto yy231;
  yy245:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy242;
    goto yy231;
  yy246:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x8F)
      goto yy242;
    goto yy231;
  yy247:
    yych = *++p;
    if (yybm[0 + yych] & 1) {
      goto yy247;
    }
    if (yych <= '>') {
      if (yych <= '9') {
        if (yych == '/')
          goto yy251;
        goto yy231;
      } else {
        if (yych <= ':')
          goto yy260;
        if (yych <= '=')
          goto yy231;
        goto yy252;
      }
    } else {
      if (yych <= '^') {
        if (yych <= '@')
          goto yy231;
        if (yych <= 'Z')
          goto yy260;
        goto yy231;
      } else {
        if (yych == '`')
          goto yy231;
        if (yych <= 'z')
          goto yy260;
        goto yy231;
      }
    }
  yy249:
    yych = *++p;
  yy250:
    if (yybm[0 + yych] & 1) {
      goto yy247;
    }
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych == '-')
          goto yy249;
        goto yy231;
      } else {
        if (yych <= '/')
          goto yy251;
        if (yych <= '9')
          goto yy249;
        goto yy231;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy252;
        if (yych <= '@')
          goto yy231;
        goto yy249;
      } else {
        if (yych <= '`')
          goto yy231;
        if (yych <= 'z')
          goto yy249;
        goto yy231;
      }
    }
  yy251:
    yych = *++p;
    if (yych != '>')
      goto yy231;
  yy252:
    ++p;
    { return (bufsize_t)(p - start); }
  yy254:
    yych = *++p;
    if (yych == '-')
      goto yy264;
    if (yych == '>')
      goto yy231;
    goto yy263;
  yy255:
    yych = *++p;
    if (yybm[0 + yych] & 2) {
      goto yy255;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy231;
        if (yych <= '>')
          goto yy252;
        goto yy231;
      } else {
        if (yych <= 0xDF)
          goto yy272;
        if (yych <= 0xE0)
          goto yy273;
        goto yy274;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy275;
        if (yych <= 0xEF)
          goto yy274;
        goto yy276;
      } else {
        if (yych <= 0xF3)
          goto yy277;
        if (yych <= 0xF4)
          goto yy278;
        goto yy231;
      }
    }
  yy257:
    yych = *++p;
    if (yych == 'D')
      goto yy279;
    if (yych == 'd')
      goto yy279;
    goto yy231;
  yy258:
    yych = *++p;
    if (yych <= 0x1F) {
      if (yych <= 0x08)
        goto yy231;
      if (yych <= '\r')
        goto yy258;
      goto yy231;
    } else {
      if (yych <= ' ')
        goto yy258;
      if (yych == '>')
        goto yy252;
      goto yy231;
    }
  yy260:
    yych = *++p;
    if (yybm[0 + yych] & 4) {
      goto yy260;
    }
    if (yych <= ',') {
      if (yych <= '\r') {
        if (yych <= 0x08)
          goto yy231;
        goto yy280;
      } else {
        if (yych == ' ')
          goto yy280;
        goto yy231;
      }
    } else {
      if (yych <= '<') {
        if (yych <= '/')
          goto yy251;
        goto yy231;
      } else {
        if (yych <= '=')
          goto yy282;
        if (yych <= '>')
          goto yy252;
        goto yy231;
      }
    }
  yy262:
    yych = *++p;
  yy263:
    if (yybm[0 + yych] & 8) {
      goto yy262;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy231;
        if (yych <= '-')
          goto yy284;
        goto yy231;
      } else {
        if (yych <= 0xDF)
          goto yy265;
        if (yych <= 0xE0)
          goto yy266;
        goto yy267;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy268;
        if (yych <= 0xEF)
          goto yy267;
        goto yy269;
      } else {
        if (yych <= 0xF3)
          goto yy270;
        if (yych <= 0xF4)
          goto yy271;
        goto yy231;
      }
    }
  yy264:
    yych = *++p;
    if (yych == '-')
      goto yy251;
    if (yych == '>')
      goto yy231;
    goto yy263;
  yy265:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy262;
    goto yy231;
  yy266:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy265;
    goto yy231;
  yy267:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy265;
    goto yy231;
  yy268:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x9F)
      goto yy265;
    goto yy231;
  yy269:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy267;
    goto yy231;
  yy270:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy267;
    goto yy231;
  yy271:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x8F)
      goto yy267;
    goto yy231;
  yy272:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy255;
    goto yy231;
  yy273:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy272;
    goto yy231;
  yy274:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy272;
    goto yy231;
  yy275:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x9F)
      goto yy272;
    goto yy231;
  yy276:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy274;
    goto yy231;
  yy277:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy274;
    goto yy231;
  yy278:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x8F)
      goto yy274;
    goto yy231;
  yy279:
    yych = *++p;
    if (yych == 'A')
      goto yy285;
    if (yych == 'a')
      goto yy285;
    goto yy231;
  yy280:
    yych = *++p;
    if (yych <= '<') {
      if (yych <= ' ') {
        if (yych <= 0x08)
          goto yy231;
        if (yych <= '\r')
          goto yy280;
        if (yych <= 0x1F)
          goto yy231;
        goto yy280;
      } else {
        if (yych <= '/') {
          if (yych <= '.')
            goto yy231;
          goto yy251;
        } else {
          if (yych == ':')
            goto yy260;
          goto yy231;
        }
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '=')
          goto yy282;
        if (yych <= '>')
          goto yy252;
        if (yych <= '@')
          goto yy231;
        goto yy260;
      } else {
        if (yych <= '_') {
          if (yych <= '^')
            goto yy231;
          goto yy260;
        } else {
          if (yych <= '`')
            goto yy231;
          if (yych <= 'z')
            goto yy260;
          goto yy231;
        }
      }
    }
  yy282:
    yych = *++p;
    if (yybm[0 + yych] & 16) {
      goto yy286;
    }
    if (yych <= 0xE0) {
      if (yych <= '"') {
        if (yych <= 0x00)
          goto yy231;
        if (yych <= ' ')
          goto yy282;
        goto yy288;
      } else {
        if (yych <= '\'')
          goto yy290;
        if (yych <= 0xC1)
          goto yy231;
        if (yych <= 0xDF)
          goto yy292;
        goto yy293;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy295;
        goto yy294;
      } else {
        if (yych <= 0xF0)
          goto yy296;
        if (yych <= 0xF3)
          goto yy297;
        if (yych <= 0xF4)
          goto yy298;
        goto yy231;
      }
    }
  yy284:
    yych = *++p;
    if (yybm[0 + yych] & 8) {
      goto yy262;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy231;
        if (yych <= '-')
          goto yy251;
        goto yy231;
      } else {
        if (yych <= 0xDF)
          goto yy265;
        if (yych <= 0xE0)
          goto yy266;
        goto yy267;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy268;
        if (yych <= 0xEF)
          goto yy267;
        goto yy269;
      } else {
        if (yych <= 0xF3)
          goto yy270;
        if (yych <= 0xF4)
          goto yy271;
        goto yy231;
      }
    }
  yy285:
    yych = *++p;
    if (yych == 'T')
      goto yy299;
    if (yych == 't')
      goto yy299;
    goto yy231;
  yy286:
    yych = *++p;
    if (yybm[0 + yych] & 16) {
      goto yy286;
    }
    if (yych <= 0xE0) {
      if (yych <= '=') {
        if (yych <= 0x00)
          goto yy231;
        if (yych <= ' ')
          goto yy247;
        goto yy231;
      } else {
        if (yych <= '>')
          goto yy252;
        if (yych <= 0xC1)
          goto yy231;
        if (yych <= 0xDF)
          goto yy292;
        goto yy293;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy295;
        goto yy294;
      } else {
        if (yych <= 0xF0)
          goto yy296;
        if (yych <= 0xF3)
          goto yy297;
        if (yych <= 0xF4)
          goto yy298;
        goto yy231;
      }
    }
  yy288:
    yych = *++p;
    if (yybm[0 + yych] & 32) {
      goto yy288;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy231;
        if (yych <= '"')
          goto yy300;
        goto yy231;
      } else {
        if (yych <= 0xDF)
          goto yy301;
        if (yych <= 0xE0)
          goto yy302;
        goto yy303;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy304;
        if (yych <= 0xEF)
          goto yy303;
        goto yy305;
      } else {
        if (yych <= 0xF3)
          goto yy306;
        if (yych <= 0xF4)
          goto yy307;
        goto yy231;
      }
    }
  yy290:
    yych = *++p;
    if (yybm[0 + yych] & 64) {
      goto yy290;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy231;
        if (yych <= '\'')
          goto yy300;
        goto yy231;
      } else {
        if (yych <= 0xDF)
          goto yy308;
        if (yych <= 0xE0)
          goto yy309;
        goto yy310;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy311;
        if (yych <= 0xEF)
          goto yy310;
        goto yy312;
      } else {
        if (yych <= 0xF3)
          goto yy313;
        if (yych <= 0xF4)
          goto yy314;
        goto yy231;
      }
    }
  yy292:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy286;
    goto yy231;
  yy293:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy292;
    goto yy231;
  yy294:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy292;
    goto yy231;
  yy295:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x9F)
      goto yy292;
    goto yy231;
  yy296:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy294;
    goto yy231;
  yy297:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy294;
    goto yy231;
  yy298:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x8F)
      goto yy294;
    goto yy231;
  yy299:
    yych = *++p;
    if (yych == 'A')
      goto yy315;
    if (yych == 'a')
      goto yy315;
    goto yy231;
  yy300:
    yych = *++p;
    if (yybm[0 + yych] & 1) {
      goto yy247;
    }
    if (yych == '/')
      goto yy251;
    if (yych == '>')
      goto yy252;
    goto yy231;
  yy301:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy288;
    goto yy231;
  yy302:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy301;
    goto yy231;
  yy303:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy301;
    goto yy231;
  yy304:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x9F)
      goto yy301;
    goto yy231;
  yy305:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy303;
    goto yy231;
  yy306:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy303;
    goto yy231;
  yy307:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x8F)
      goto yy303;
    goto yy231;
  yy308:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy290;
    goto yy231;
  yy309:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy308;
    goto yy231;
  yy310:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy308;
    goto yy231;
  yy311:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x9F)
      goto yy308;
    goto yy231;
  yy312:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy310;
    goto yy231;
  yy313:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy310;
    goto yy231;
  yy314:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x8F)
      goto yy310;
    goto yy231;
  yy315:
    yych = *++p;
    if (yych != '[')
      goto yy231;
  yy316:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy316;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy231;
        if (yych >= '^')
          goto yy231;
      } else {
        if (yych <= 0xDF)
          goto yy319;
        if (yych <= 0xE0)
          goto yy320;
        goto yy321;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy322;
        if (yych <= 0xEF)
          goto yy321;
        goto yy323;
      } else {
        if (yych <= 0xF3)
          goto yy324;
        if (yych <= 0xF4)
          goto yy325;
        goto yy231;
      }
    }
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy316;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy231;
        if (yych <= ']')
          goto yy326;
        goto yy231;
      } else {
        if (yych <= 0xDF)
          goto yy319;
        if (yych <= 0xE0)
          goto yy320;
        goto yy321;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy322;
        if (yych <= 0xEF)
          goto yy321;
        goto yy323;
      } else {
        if (yych <= 0xF3)
          goto yy324;
        if (yych <= 0xF4)
          goto yy325;
        goto yy231;
      }
    }
  yy319:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy316;
    goto yy231;
  yy320:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy319;
    goto yy231;
  yy321:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy319;
    goto yy231;
  yy322:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x9F)
      goto yy319;
    goto yy231;
  yy323:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy321;
    goto yy231;
  yy324:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0xBF)
      goto yy321;
    goto yy231;
  yy325:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy231;
    if (yych <= 0x8F)
      goto yy321;
    goto yy231;
  yy326:
    yych = *++p;
    if (yych <= 0xE0) {
      if (yych <= '>') {
        if (yych <= 0x00)
          goto yy231;
        if (yych <= '=')
          goto yy316;
        goto yy252;
      } else {
        if (yych <= 0x7F)
          goto yy316;
        if (yych <= 0xC1)
          goto yy231;
        if (yych <= 0xDF)
          goto yy319;
        goto yy320;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy322;
        goto yy321;
      } else {
        if (yych <= 0xF0)
          goto yy323;
        if (yych <= 0xF3)
          goto yy324;
        if (yych <= 0xF4)
          goto yy325;
        goto yy231;
      }
    }
  }
}

// Try to match an HTML block tag start line, returning
// an integer code for the type of block (1-6, matching the spec).
// #7 is handled by a separate function, below.
bufsize_t _scan_html_block_start(const unsigned char *p) {
  const unsigned char *marker = NULL;

  {
    unsigned char yych;
    yych = *p;
    if (yych == '<')
      goto yy331;
    ++p;
  yy330 : { return 0; }
  yy331:
    yych = *(marker = ++p);
    switch (yych) {
    case '!':
      goto yy332;
    case '/':
      goto yy334;
    case '?':
      goto yy335;
    case 'A':
    case 'a':
      goto yy337;
    case 'B':
    case 'b':
      goto yy338;
    case 'C':
    case 'c':
      goto yy339;
    case 'D':
    case 'd':
      goto yy340;
    case 'F':
    case 'f':
      goto yy341;
    case 'H':
    case 'h':
      goto yy342;
    case 'I':
    case 'i':
      goto yy343;
    case 'L':
    case 'l':
      goto yy344;
    case 'M':
    case 'm':
      goto yy345;
    case 'N':
    case 'n':
      goto yy346;
    case 'O':
    case 'o':
      goto yy347;
    case 'P':
    case 'p':
      goto yy348;
    case 'S':
    case 's':
      goto yy349;
    case 'T':
    case 't':
      goto yy350;
    case 'U':
    case 'u':
      goto yy351;
    default:
      goto yy330;
    }
  yy332:
    yych = *++p;
    if (yych <= '@') {
      if (yych == '-')
        goto yy352;
    } else {
      if (yych <= 'Z')
        goto yy353;
      if (yych <= '[')
        goto yy355;
    }
  yy333:
    p = marker;
    goto yy330;
  yy334:
    yych = *++p;
    switch (yych) {
    case 'A':
    case 'a':
      goto yy337;
    case 'B':
    case 'b':
      goto yy338;
    case 'C':
    case 'c':
      goto yy339;
    case 'D':
    case 'd':
      goto yy340;
    case 'F':
    case 'f':
      goto yy341;
    case 'H':
    case 'h':
      goto yy342;
    case 'I':
    case 'i':
      goto yy343;
    case 'L':
    case 'l':
      goto yy344;
    case 'M':
    case 'm':
      goto yy345;
    case 'N':
    case 'n':
      goto yy346;
    case 'O':
    case 'o':
      goto yy347;
    case 'P':
    case 'p':
      goto yy356;
    case 'S':
    case 's':
      goto yy357;
    case 'T':
    case 't':
      goto yy358;
    case 'U':
    case 'u':
      goto yy351;
    default:
      goto yy333;
    }
  yy335:
    ++p;
    { return 3; }
  yy337:
    yych = *++p;
    if (yych <= 'S') {
      if (yych <= 'D') {
        if (yych <= 'C')
          goto yy333;
        goto yy359;
      } else {
        if (yych <= 'Q')
          goto yy333;
        if (yych <= 'R')
          goto yy360;
        goto yy361;
      }
    } else {
      if (yych <= 'q') {
        if (yych == 'd')
          goto yy359;
        goto yy333;
      } else {
        if (yych <= 'r')
          goto yy360;
        if (yych <= 's')
          goto yy361;
        goto yy333;
      }
    }
  yy338:
    yych = *++p;
    if (yych <= 'O') {
      if (yych <= 'K') {
        if (yych == 'A')
          goto yy362;
        goto yy333;
      } else {
        if (yych <= 'L')
          goto yy363;
        if (yych <= 'N')
          goto yy333;
        goto yy364;
      }
    } else {
      if (yych <= 'k') {
        if (yych == 'a')
          goto yy362;
        goto yy333;
      } else {
        if (yych <= 'l')
          goto yy363;
        if (yych == 'o')
          goto yy364;
        goto yy333;
      }
    }
  yy339:
    yych = *++p;
    if (yych <= 'O') {
      if (yych <= 'D') {
        if (yych == 'A')
          goto yy365;
        goto yy333;
      } else {
        if (yych <= 'E')
          goto yy366;
        if (yych <= 'N')
          goto yy333;
        goto yy367;
      }
    } else {
      if (yych <= 'd') {
        if (yych == 'a')
          goto yy365;
        goto yy333;
      } else {
        if (yych <= 'e')
          goto yy366;
        if (yych == 'o')
          goto yy367;
        goto yy333;
      }
    }
  yy340:
    yych = *++p;
    switch (yych) {
    case 'D':
    case 'L':
    case 'T':
    case 'd':
    case 'l':
    case 't':
      goto yy368;
    case 'E':
    case 'e':
      goto yy369;
    case 'I':
    case 'i':
      goto yy370;
    default:
      goto yy333;
    }
  yy341:
    yych = *++p;
    if (yych <= 'R') {
      if (yych <= 'N') {
        if (yych == 'I')
          goto yy371;
        goto yy333;
      } else {
        if (yych <= 'O')
          goto yy372;
        if (yych <= 'Q')
          goto yy333;
        goto yy373;
      }
    } else {
      if (yych <= 'n') {
        if (yych == 'i')
          goto yy371;
        goto yy333;
      } else {
        if (yych <= 'o')
          goto yy372;
        if (yych == 'r')
          goto yy373;
        goto yy333;
      }
    }
  yy342:
    yych = *++p;
    if (yych <= 'S') {
      if (yych <= 'D') {
        if (yych <= '0')
          goto yy333;
        if (yych <= '6')
          goto yy368;
        goto yy333;
      } else {
        if (yych <= 'E')
          goto yy374;
        if (yych == 'R')
          goto yy368;
        goto yy333;
      }
    } else {
      if (yych <= 'q') {
        if (yych <= 'T')
          goto yy375;
        if (yych == 'e')
          goto yy374;
        goto yy333;
      } else {
        if (yych <= 'r')
          goto yy368;
        if (yych == 't')
          goto yy375;
        goto yy333;
      }
    }
  yy343:
    yych = *++p;
    if (yych == 'F')
      goto yy376;
    if (yych == 'f')
      goto yy376;
    goto yy333;
  yy344:
    yych = *++p;
    if (yych <= 'I') {
      if (yych == 'E')
        goto yy377;
      if (yych <= 'H')
        goto yy333;
      goto yy378;
    } else {
      if (yych <= 'e') {
        if (yych <= 'd')
          goto yy333;
        goto yy377;
      } else {
        if (yych == 'i')
          goto yy378;
        goto yy333;
      }
    }
  yy345:
    yych = *++p;
    if (yych <= 'E') {
      if (yych == 'A')
        goto yy379;
      if (yych <= 'D')
        goto yy333;
      goto yy380;
    } else {
      if (yych <= 'a') {
        if (yych <= '`')
          goto yy333;
        goto yy379;
      } else {
        if (yych == 'e')
          goto yy380;
        goto yy333;
      }
    }
  yy346:
    yych = *++p;
    if (yych <= 'O') {
      if (yych == 'A')
        goto yy381;
      if (yych <= 'N')
        goto yy333;
      goto yy382;
    } else {
      if (yych <= 'a') {
        if (yych <= '`')
          goto yy333;
        goto yy381;
      } else {
        if (yych == 'o')
          goto yy382;
        goto yy333;
      }
    }
  yy347:
    yych = *++p;
    if (yych <= 'P') {
      if (yych == 'L')
        goto yy368;
      if (yych <= 'O')
        goto yy333;
      goto yy383;
    } else {
      if (yych <= 'l') {
        if (yych <= 'k')
          goto yy333;
        goto yy368;
      } else {
        if (yych == 'p')
          goto yy383;
        goto yy333;
      }
    }
  yy348:
    yych = *++p;
    if (yych <= '>') {
      if (yych <= ' ') {
        if (yych <= 0x08)
          goto yy333;
        if (yych <= '\r')
          goto yy384;
        if (yych <= 0x1F)
          goto yy333;
        goto yy384;
      } else {
        if (yych == '/')
          goto yy386;
        if (yych <= '=')
          goto yy333;
        goto yy384;
      }
    } else {
      if (yych <= 'R') {
        if (yych == 'A')
          goto yy387;
        if (yych <= 'Q')
          goto yy333;
        goto yy388;
      } else {
        if (yych <= 'a') {
          if (yych <= '`')
            goto yy333;
          goto yy387;
        } else {
          if (yych == 'r')
            goto yy388;
          goto yy333;
        }
      }
    }
  yy349:
    yych = *++p;
    switch (yych) {
    case 'C':
    case 'c':
      goto yy389;
    case 'E':
    case 'e':
      goto yy390;
    case 'O':
    case 'o':
      goto yy391;
    case 'T':
    case 't':
      goto yy392;
    case 'U':
    case 'u':
      goto yy393;
    default:
      goto yy333;
    }
  yy350:
    yych = *++p;
    switch (yych) {
    case 'A':
    case 'a':
      goto yy394;
    case 'B':
    case 'b':
      goto yy395;
    case 'D':
    case 'd':
      goto yy368;
    case 'E':
    case 'e':
      goto yy396;
    case 'F':
    case 'f':
      goto yy397;
    case 'H':
    case 'h':
      goto yy398;
    case 'I':
    case 'i':
      goto yy399;
    case 'R':
    case 'r':
      goto yy400;
    default:
      goto yy333;
    }
  yy351:
    yych = *++p;
    if (yych == 'L')
      goto yy368;
    if (yych == 'l')
      goto yy368;
    goto yy333;
  yy352:
    yych = *++p;
    if (yych == '-')
      goto yy401;
    goto yy333;
  yy353:
    ++p;
    { return 4; }
  yy355:
    yych = *++p;
    if (yych == 'C')
      goto yy403;
    if (yych == 'c')
      goto yy403;
    goto yy333;
  yy356:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy333;
        if (yych <= '\r')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= ' ')
          goto yy384;
        if (yych <= '.')
          goto yy333;
        goto yy386;
      }
    } else {
      if (yych <= '@') {
        if (yych == '>')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= 'A')
          goto yy387;
        if (yych == 'a')
          goto yy387;
        goto yy333;
      }
    }
  yy357:
    yych = *++p;
    if (yych <= 'U') {
      if (yych <= 'N') {
        if (yych == 'E')
          goto yy390;
        goto yy333;
      } else {
        if (yych <= 'O')
          goto yy391;
        if (yych <= 'T')
          goto yy333;
        goto yy393;
      }
    } else {
      if (yych <= 'n') {
        if (yych == 'e')
          goto yy390;
        goto yy333;
      } else {
        if (yych <= 'o')
          goto yy391;
        if (yych == 'u')
          goto yy393;
        goto yy333;
      }
    }
  yy358:
    yych = *++p;
    switch (yych) {
    case 'A':
    case 'a':
      goto yy394;
    case 'B':
    case 'b':
      goto yy395;
    case 'D':
    case 'd':
      goto yy368;
    case 'F':
    case 'f':
      goto yy397;
    case 'H':
    case 'h':
      goto yy398;
    case 'I':
    case 'i':
      goto yy399;
    case 'R':
    case 'r':
      goto yy400;
    default:
      goto yy333;
    }
  yy359:
    yych = *++p;
    if (yych == 'D')
      goto yy404;
    if (yych == 'd')
      goto yy404;
    goto yy333;
  yy360:
    yych = *++p;
    if (yych == 'T')
      goto yy405;
    if (yych == 't')
      goto yy405;
    goto yy333;
  yy361:
    yych = *++p;
    if (yych == 'I')
      goto yy406;
    if (yych == 'i')
      goto yy406;
    goto yy333;
  yy362:
    yych = *++p;
    if (yych == 'S')
      goto yy407;
    if (yych == 's')
      goto yy407;
    goto yy333;
  yy363:
    yych = *++p;
    if (yych == 'O')
      goto yy408;
    if (yych == 'o')
      goto yy408;
    goto yy333;
  yy364:
    yych = *++p;
    if (yych == 'D')
      goto yy409;
    if (yych == 'd')
      goto yy409;
    goto yy333;
  yy365:
    yych = *++p;
    if (yych == 'P')
      goto yy410;
    if (yych == 'p')
      goto yy410;
    goto yy333;
  yy366:
    yych = *++p;
    if (yych == 'N')
      goto yy411;
    if (yych == 'n')
      goto yy411;
    goto yy333;
  yy367:
    yych = *++p;
    if (yych == 'L')
      goto yy412;
    if (yych == 'l')
      goto yy412;
    goto yy333;
  yy368:
    yych = *++p;
    if (yych <= ' ') {
      if (yych <= 0x08)
        goto yy333;
      if (yych <= '\r')
        goto yy384;
      if (yych <= 0x1F)
        goto yy333;
      goto yy384;
    } else {
      if (yych <= '/') {
        if (yych <= '.')
          goto yy333;
        goto yy386;
      } else {
        if (yych == '>')
          goto yy384;
        goto yy333;
      }
    }
  yy369:
    yych = *++p;
    if (yych == 'T')
      goto yy413;
    if (yych == 't')
      goto yy413;
    goto yy333;
  yy370:
    yych = *++p;
    if (yych <= 'V') {
      if (yych <= 'Q') {
        if (yych == 'A')
          goto yy414;
        goto yy333;
      } else {
        if (yych <= 'R')
          goto yy368;
        if (yych <= 'U')
          goto yy333;
        goto yy368;
      }
    } else {
      if (yych <= 'q') {
        if (yych == 'a')
          goto yy414;
        goto yy333;
      } else {
        if (yych <= 'r')
          goto yy368;
        if (yych == 'v')
          goto yy368;
        goto yy333;
      }
    }
  yy371:
    yych = *++p;
    if (yych <= 'G') {
      if (yych == 'E')
        goto yy415;
      if (yych <= 'F')
        goto yy333;
      goto yy416;
    } else {
      if (yych <= 'e') {
        if (yych <= 'd')
          goto yy333;
        goto yy415;
      } else {
        if (yych == 'g')
          goto yy416;
        goto yy333;
      }
    }
  yy372:
    yych = *++p;
    if (yych <= 'R') {
      if (yych == 'O')
        goto yy411;
      if (yych <= 'Q')
        goto yy333;
      goto yy417;
    } else {
      if (yych <= 'o') {
        if (yych <= 'n')
          goto yy333;
        goto yy411;
      } else {
        if (yych == 'r')
          goto yy417;
        goto yy333;
      }
    }
  yy373:
    yych = *++p;
    if (yych == 'A')
      goto yy418;
    if (yych == 'a')
      goto yy418;
    goto yy333;
  yy374:
    yych = *++p;
    if (yych == 'A')
      goto yy419;
    if (yych == 'a')
      goto yy419;
    goto yy333;
  yy375:
    yych = *++p;
    if (yych == 'M')
      goto yy351;
    if (yych == 'm')
      goto yy351;
    goto yy333;
  yy376:
    yych = *++p;
    if (yych == 'R')
      goto yy420;
    if (yych == 'r')
      goto yy420;
    goto yy333;
  yy377:
    yych = *++p;
    if (yych == 'G')
      goto yy421;
    if (yych == 'g')
      goto yy421;
    goto yy333;
  yy378:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy333;
        if (yych <= '\r')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= ' ')
          goto yy384;
        if (yych <= '.')
          goto yy333;
        goto yy386;
      }
    } else {
      if (yych <= 'M') {
        if (yych == '>')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= 'N')
          goto yy422;
        if (yych == 'n')
          goto yy422;
        goto yy333;
      }
    }
  yy379:
    yych = *++p;
    if (yych == 'I')
      goto yy423;
    if (yych == 'i')
      goto yy423;
    goto yy333;
  yy380:
    yych = *++p;
    if (yych == 'N')
      goto yy424;
    if (yych == 'n')
      goto yy424;
    goto yy333;
  yy381:
    yych = *++p;
    if (yych == 'V')
      goto yy368;
    if (yych == 'v')
      goto yy368;
    goto yy333;
  yy382:
    yych = *++p;
    if (yych == 'F')
      goto yy425;
    if (yych == 'f')
      goto yy425;
    goto yy333;
  yy383:
    yych = *++p;
    if (yych == 'T')
      goto yy426;
    if (yych == 't')
      goto yy426;
    goto yy333;
  yy384:
    ++p;
    { return 6; }
  yy386:
    yych = *++p;
    if (yych == '>')
      goto yy384;
    goto yy333;
  yy387:
    yych = *++p;
    if (yych == 'R')
      goto yy427;
    if (yych == 'r')
      goto yy427;
    goto yy333;
  yy388:
    yych = *++p;
    if (yych == 'E')
      goto yy428;
    if (yych == 'e')
      goto yy428;
    goto yy333;
  yy389:
    yych = *++p;
    if (yych == 'R')
      goto yy429;
    if (yych == 'r')
      goto yy429;
    goto yy333;
  yy390:
    yych = *++p;
    if (yych == 'C')
      goto yy410;
    if (yych == 'c')
      goto yy410;
    goto yy333;
  yy391:
    yych = *++p;
    if (yych == 'U')
      goto yy430;
    if (yych == 'u')
      goto yy430;
    goto yy333;
  yy392:
    yych = *++p;
    if (yych == 'Y')
      goto yy431;
    if (yych == 'y')
      goto yy431;
    goto yy333;
  yy393:
    yych = *++p;
    if (yych == 'M')
      goto yy432;
    if (yych == 'm')
      goto yy432;
    goto yy333;
  yy394:
    yych = *++p;
    if (yych == 'B')
      goto yy433;
    if (yych == 'b')
      goto yy433;
    goto yy333;
  yy395:
    yych = *++p;
    if (yych == 'O')
      goto yy364;
    if (yych == 'o')
      goto yy364;
    goto yy333;
  yy396:
    yych = *++p;
    if (yych == 'X')
      goto yy434;
    if (yych == 'x')
      goto yy434;
    goto yy333;
  yy397:
    yych = *++p;
    if (yych == 'O')
      goto yy435;
    if (yych == 'o')
      goto yy435;
    goto yy333;
  yy398:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy333;
        if (yych <= '\r')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= ' ')
          goto yy384;
        if (yych <= '.')
          goto yy333;
        goto yy386;
      }
    } else {
      if (yych <= 'D') {
        if (yych == '>')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= 'E')
          goto yy436;
        if (yych == 'e')
          goto yy436;
        goto yy333;
      }
    }
  yy399:
    yych = *++p;
    if (yych == 'T')
      goto yy433;
    if (yych == 't')
      goto yy433;
    goto yy333;
  yy400:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy333;
        if (yych <= '\r')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= ' ')
          goto yy384;
        if (yych <= '.')
          goto yy333;
        goto yy386;
      }
    } else {
      if (yych <= '@') {
        if (yych == '>')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= 'A')
          goto yy437;
        if (yych == 'a')
          goto yy437;
        goto yy333;
      }
    }
  yy401:
    ++p;
    { return 2; }
  yy403:
    yych = *++p;
    if (yych == 'D')
      goto yy438;
    if (yych == 'd')
      goto yy438;
    goto yy333;
  yy404:
    yych = *++p;
    if (yych == 'R')
      goto yy439;
    if (yych == 'r')
      goto yy439;
    goto yy333;
  yy405:
    yych = *++p;
    if (yych == 'I')
      goto yy440;
    if (yych == 'i')
      goto yy440;
    goto yy333;
  yy406:
    yych = *++p;
    if (yych == 'D')
      goto yy441;
    if (yych == 'd')
      goto yy441;
    goto yy333;
  yy407:
    yych = *++p;
    if (yych == 'E')
      goto yy442;
    if (yych == 'e')
      goto yy442;
    goto yy333;
  yy408:
    yych = *++p;
    if (yych == 'C')
      goto yy443;
    if (yych == 'c')
      goto yy443;
    goto yy333;
  yy409:
    yych = *++p;
    if (yych == 'Y')
      goto yy368;
    if (yych == 'y')
      goto yy368;
    goto yy333;
  yy410:
    yych = *++p;
    if (yych == 'T')
      goto yy444;
    if (yych == 't')
      goto yy444;
    goto yy333;
  yy411:
    yych = *++p;
    if (yych == 'T')
      goto yy445;
    if (yych == 't')
      goto yy445;
    goto yy333;
  yy412:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy333;
        if (yych <= '\r')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= ' ')
          goto yy384;
        if (yych <= '.')
          goto yy333;
        goto yy386;
      }
    } else {
      if (yych <= 'F') {
        if (yych == '>')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= 'G')
          goto yy446;
        if (yych == 'g')
          goto yy446;
        goto yy333;
      }
    }
  yy413:
    yych = *++p;
    if (yych == 'A')
      goto yy447;
    if (yych == 'a')
      goto yy447;
    goto yy333;
  yy414:
    yych = *++p;
    if (yych == 'L')
      goto yy448;
    if (yych == 'l')
      goto yy448;
    goto yy333;
  yy415:
    yych = *++p;
    if (yych == 'L')
      goto yy449;
    if (yych == 'l')
      goto yy449;
    goto yy333;
  yy416:
    yych = *++p;
    if (yych <= 'U') {
      if (yych == 'C')
        goto yy450;
      if (yych <= 'T')
        goto yy333;
      goto yy451;
    } else {
      if (yych <= 'c') {
        if (yych <= 'b')
          goto yy333;
        goto yy450;
      } else {
        if (yych == 'u')
          goto yy451;
        goto yy333;
      }
    }
  yy417:
    yych = *++p;
    if (yych == 'M')
      goto yy368;
    if (yych == 'm')
      goto yy368;
    goto yy333;
  yy418:
    yych = *++p;
    if (yych == 'M')
      goto yy452;
    if (yych == 'm')
      goto yy452;
    goto yy333;
  yy419:
    yych = *++p;
    if (yych == 'D')
      goto yy453;
    if (yych == 'd')
      goto yy453;
    goto yy333;
  yy420:
    yych = *++p;
    if (yych == 'A')
      goto yy454;
    if (yych == 'a')
      goto yy454;
    goto yy333;
  yy421:
    yych = *++p;
    if (yych == 'E')
      goto yy455;
    if (yych == 'e')
      goto yy455;
    goto yy333;
  yy422:
    yych = *++p;
    if (yych == 'K')
      goto yy368;
    if (yych == 'k')
      goto yy368;
    goto yy333;
  yy423:
    yych = *++p;
    if (yych == 'N')
      goto yy368;
    if (yych == 'n')
      goto yy368;
    goto yy333;
  yy424:
    yych = *++p;
    if (yych == 'U')
      goto yy456;
    if (yych == 'u')
      goto yy456;
    goto yy333;
  yy425:
    yych = *++p;
    if (yych == 'R')
      goto yy457;
    if (yych == 'r')
      goto yy457;
    goto yy333;
  yy426:
    yych = *++p;
    if (yych <= 'I') {
      if (yych == 'G')
        goto yy446;
      if (yych <= 'H')
        goto yy333;
      goto yy458;
    } else {
      if (yych <= 'g') {
        if (yych <= 'f')
          goto yy333;
        goto yy446;
      } else {
        if (yych == 'i')
          goto yy458;
        goto yy333;
      }
    }
  yy427:
    yych = *++p;
    if (yych == 'A')
      goto yy417;
    if (yych == 'a')
      goto yy417;
    goto yy333;
  yy428:
    yych = *++p;
    if (yych <= 0x1F) {
      if (yych <= 0x08)
        goto yy333;
      if (yych <= '\r')
        goto yy459;
      goto yy333;
    } else {
      if (yych <= ' ')
        goto yy459;
      if (yych == '>')
        goto yy459;
      goto yy333;
    }
  yy429:
    yych = *++p;
    if (yych == 'I')
      goto yy461;
    if (yych == 'i')
      goto yy461;
    goto yy333;
  yy430:
    yych = *++p;
    if (yych == 'R')
      goto yy462;
    if (yych == 'r')
      goto yy462;
    goto yy333;
  yy431:
    yych = *++p;
    if (yych == 'L')
      goto yy388;
    if (yych == 'l')
      goto yy388;
    goto yy333;
  yy432:
    yych = *++p;
    if (yych == 'M')
      goto yy463;
    if (yych == 'm')
      goto yy463;
    goto yy333;
  yy433:
    yych = *++p;
    if (yych == 'L')
      goto yy441;
    if (yych == 'l')
      goto yy441;
    goto yy333;
  yy434:
    yych = *++p;
    if (yych == 'T')
      goto yy464;
    if (yych == 't')
      goto yy464;
    goto yy333;
  yy435:
    yych = *++p;
    if (yych == 'O')
      goto yy465;
    if (yych == 'o')
      goto yy465;
    goto yy333;
  yy436:
    yych = *++p;
    if (yych == 'A')
      goto yy466;
    if (yych == 'a')
      goto yy466;
    goto yy333;
  yy437:
    yych = *++p;
    if (yych == 'C')
      goto yy422;
    if (yych == 'c')
      goto yy422;
    goto yy333;
  yy438:
    yych = *++p;
    if (yych == 'A')
      goto yy467;
    if (yych == 'a')
      goto yy467;
    goto yy333;
  yy439:
    yych = *++p;
    if (yych == 'E')
      goto yy468;
    if (yych == 'e')
      goto yy468;
    goto yy333;
  yy440:
    yych = *++p;
    if (yych == 'C')
      goto yy433;
    if (yych == 'c')
      goto yy433;
    goto yy333;
  yy441:
    yych = *++p;
    if (yych == 'E')
      goto yy368;
    if (yych == 'e')
      goto yy368;
    goto yy333;
  yy442:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy333;
        if (yych <= '\r')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= ' ')
          goto yy384;
        if (yych <= '.')
          goto yy333;
        goto yy386;
      }
    } else {
      if (yych <= 'E') {
        if (yych == '>')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= 'F')
          goto yy469;
        if (yych == 'f')
          goto yy469;
        goto yy333;
      }
    }
  yy443:
    yych = *++p;
    if (yych == 'K')
      goto yy470;
    if (yych == 'k')
      goto yy470;
    goto yy333;
  yy444:
    yych = *++p;
    if (yych == 'I')
      goto yy458;
    if (yych == 'i')
      goto yy458;
    goto yy333;
  yy445:
    yych = *++p;
    if (yych == 'E')
      goto yy471;
    if (yych == 'e')
      goto yy471;
    goto yy333;
  yy446:
    yych = *++p;
    if (yych == 'R')
      goto yy472;
    if (yych == 'r')
      goto yy472;
    goto yy333;
  yy447:
    yych = *++p;
    if (yych == 'I')
      goto yy473;
    if (yych == 'i')
      goto yy473;
    goto yy333;
  yy448:
    yych = *++p;
    if (yych == 'O')
      goto yy474;
    if (yych == 'o')
      goto yy474;
    goto yy333;
  yy449:
    yych = *++p;
    if (yych == 'D')
      goto yy475;
    if (yych == 'd')
      goto yy475;
    goto yy333;
  yy450:
    yych = *++p;
    if (yych == 'A')
      goto yy365;
    if (yych == 'a')
      goto yy365;
    goto yy333;
  yy451:
    yych = *++p;
    if (yych == 'R')
      goto yy441;
    if (yych == 'r')
      goto yy441;
    goto yy333;
  yy452:
    yych = *++p;
    if (yych == 'E')
      goto yy476;
    if (yych == 'e')
      goto yy476;
    goto yy333;
  yy453:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy333;
        if (yych <= '\r')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= ' ')
          goto yy384;
        if (yych <= '.')
          goto yy333;
        goto yy386;
      }
    } else {
      if (yych <= 'D') {
        if (yych == '>')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= 'E')
          goto yy471;
        if (yych == 'e')
          goto yy471;
        goto yy333;
      }
    }
  yy454:
    yych = *++p;
    if (yych == 'M')
      goto yy441;
    if (yych == 'm')
      goto yy441;
    goto yy333;
  yy455:
    yych = *++p;
    if (yych == 'N')
      goto yy466;
    if (yych == 'n')
      goto yy466;
    goto yy333;
  yy456:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy333;
        if (yych <= '\r')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= ' ')
          goto yy384;
        if (yych <= '.')
          goto yy333;
        goto yy386;
      }
    } else {
      if (yych <= 'H') {
        if (yych == '>')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= 'I')
          goto yy477;
        if (yych == 'i')
          goto yy477;
        goto yy333;
      }
    }
  yy457:
    yych = *++p;
    if (yych == 'A')
      goto yy478;
    if (yych == 'a')
      goto yy478;
    goto yy333;
  yy458:
    yych = *++p;
    if (yych == 'O')
      goto yy423;
    if (yych == 'o')
      goto yy423;
    goto yy333;
  yy459:
    ++p;
    { return 1; }
  yy461:
    yych = *++p;
    if (yych == 'P')
      goto yy479;
    if (yych == 'p')
      goto yy479;
    goto yy333;
  yy462:
    yych = *++p;
    if (yych == 'C')
      goto yy441;
    if (yych == 'c')
      goto yy441;
    goto yy333;
  yy463:
    yych = *++p;
    if (yych == 'A')
      goto yy480;
    if (yych == 'a')
      goto yy480;
    goto yy333;
  yy464:
    yych = *++p;
    if (yych == 'A')
      goto yy481;
    if (yych == 'a')
      goto yy481;
    goto yy333;
  yy465:
    yych = *++p;
    if (yych == 'T')
      goto yy368;
    if (yych == 't')
      goto yy368;
    goto yy333;
  yy466:
    yych = *++p;
    if (yych == 'D')
      goto yy368;
    if (yych == 'd')
      goto yy368;
    goto yy333;
  yy467:
    yych = *++p;
    if (yych == 'T')
      goto yy482;
    if (yych == 't')
      goto yy482;
    goto yy333;
  yy468:
    yych = *++p;
    if (yych == 'S')
      goto yy483;
    if (yych == 's')
      goto yy483;
    goto yy333;
  yy469:
    yych = *++p;
    if (yych == 'O')
      goto yy484;
    if (yych == 'o')
      goto yy484;
    goto yy333;
  yy470:
    yych = *++p;
    if (yych == 'Q')
      goto yy485;
    if (yych == 'q')
      goto yy485;
    goto yy333;
  yy471:
    yych = *++p;
    if (yych == 'R')
      goto yy368;
    if (yych == 'r')
      goto yy368;
    goto yy333;
  yy472:
    yych = *++p;
    if (yych == 'O')
      goto yy486;
    if (yych == 'o')
      goto yy486;
    goto yy333;
  yy473:
    yych = *++p;
    if (yych == 'L')
      goto yy483;
    if (yych == 'l')
      goto yy483;
    goto yy333;
  yy474:
    yych = *++p;
    if (yych == 'G')
      goto yy368;
    if (yych == 'g')
      goto yy368;
    goto yy333;
  yy475:
    yych = *++p;
    if (yych == 'S')
      goto yy487;
    if (yych == 's')
      goto yy487;
    goto yy333;
  yy476:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy333;
        if (yych <= '\r')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= ' ')
          goto yy384;
        if (yych <= '.')
          goto yy333;
        goto yy386;
      }
    } else {
      if (yych <= 'R') {
        if (yych == '>')
          goto yy384;
        goto yy333;
      } else {
        if (yych <= 'S')
          goto yy487;
        if (yych == 's')
          goto yy487;
        goto yy333;
      }
    }
  yy477:
    yych = *++p;
    if (yych == 'T')
      goto yy488;
    if (yych == 't')
      goto yy488;
    goto yy333;
  yy478:
    yych = *++p;
    if (yych == 'M')
      goto yy489;
    if (yych == 'm')
      goto yy489;
    goto yy333;
  yy479:
    yych = *++p;
    if (yych == 'T')
      goto yy428;
    if (yych == 't')
      goto yy428;
    goto yy333;
  yy480:
    yych = *++p;
    if (yych == 'R')
      goto yy409;
    if (yych == 'r')
      goto yy409;
    goto yy333;
  yy481:
    yych = *++p;
    if (yych == 'R')
      goto yy490;
    if (yych == 'r')
      goto yy490;
    goto yy333;
  yy482:
    yych = *++p;
    if (yych == 'A')
      goto yy491;
    if (yych == 'a')
      goto yy491;
    goto yy333;
  yy483:
    yych = *++p;
    if (yych == 'S')
      goto yy368;
    if (yych == 's')
      goto yy368;
    goto yy333;
  yy484:
    yych = *++p;
    if (yych == 'N')
      goto yy465;
    if (yych == 'n')
      goto yy465;
    goto yy333;
  yy485:
    yych = *++p;
    if (yych == 'U')
      goto yy492;
    if (yych == 'u')
      goto yy492;
    goto yy333;
  yy486:
    yych = *++p;
    if (yych == 'U')
      goto yy493;
    if (yych == 'u')
      goto yy493;
    goto yy333;
  yy487:
    yych = *++p;
    if (yych == 'E')
      goto yy465;
    if (yych == 'e')
      goto yy465;
    goto yy333;
  yy488:
    yych = *++p;
    if (yych == 'E')
      goto yy417;
    if (yych == 'e')
      goto yy417;
    goto yy333;
  yy489:
    yych = *++p;
    if (yych == 'E')
      goto yy483;
    if (yych == 'e')
      goto yy483;
    goto yy333;
  yy490:
    yych = *++p;
    if (yych == 'E')
      goto yy494;
    if (yych == 'e')
      goto yy494;
    goto yy333;
  yy491:
    yych = *++p;
    if (yych == '[')
      goto yy495;
    goto yy333;
  yy492:
    yych = *++p;
    if (yych == 'O')
      goto yy497;
    if (yych == 'o')
      goto yy497;
    goto yy333;
  yy493:
    yych = *++p;
    if (yych == 'P')
      goto yy368;
    if (yych == 'p')
      goto yy368;
    goto yy333;
  yy494:
    yych = *++p;
    if (yych == 'A')
      goto yy428;
    if (yych == 'a')
      goto yy428;
    goto yy333;
  yy495:
    ++p;
    { return 5; }
  yy497:
    yych = *++p;
    if (yych == 'T')
      goto yy441;
    if (yych == 't')
      goto yy441;
    goto yy333;
  }
}

// Try to match an HTML block tag start line of type 7, returning
// 7 if successful, 0 if not.
bufsize_t _scan_html_block_start_7(const unsigned char *p) {
  const unsigned char *marker = NULL;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,   224, 224, 224, 224, 224, 224, 224, 224, 198, 210, 194, 198, 194,
        224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224,
        224, 224, 224, 224, 198, 224, 128, 224, 224, 224, 224, 64,  224, 224,
        224, 224, 224, 233, 232, 224, 233, 233, 233, 233, 233, 233, 233, 233,
        233, 233, 232, 224, 192, 192, 192, 224, 224, 233, 233, 233, 233, 233,
        233, 233, 233, 233, 233, 233, 233, 233, 233, 233, 233, 233, 233, 233,
        233, 233, 233, 233, 233, 233, 233, 224, 224, 224, 224, 232, 192, 233,
        233, 233, 233, 233, 233, 233, 233, 233, 233, 233, 233, 233, 233, 233,
        233, 233, 233, 233, 233, 233, 233, 233, 233, 233, 233, 224, 224, 224,
        224, 224, 0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,
    };
    yych = *p;
    if (yych == '<')
      goto yy502;
    ++p;
  yy501 : { return 0; }
  yy502:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '@') {
      if (yych != '/')
        goto yy501;
    } else {
      if (yych <= 'Z')
        goto yy505;
      if (yych <= '`')
        goto yy501;
      if (yych <= 'z')
        goto yy505;
      goto yy501;
    }
    yych = *++p;
    if (yych <= '@')
      goto yy504;
    if (yych <= 'Z')
      goto yy507;
    if (yych <= '`')
      goto yy504;
    if (yych <= 'z')
      goto yy507;
  yy504:
    p = marker;
    if (yyaccept == 0) {
      goto yy501;
    } else {
      goto yy520;
    }
  yy505:
    yych = *++p;
    if (yybm[0 + yych] & 2) {
      goto yy509;
    }
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych == '-')
          goto yy505;
        goto yy504;
      } else {
        if (yych <= '/')
          goto yy511;
        if (yych <= '9')
          goto yy505;
        goto yy504;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy512;
        if (yych <= '@')
          goto yy504;
        goto yy505;
      } else {
        if (yych <= '`')
          goto yy504;
        if (yych <= 'z')
          goto yy505;
        goto yy504;
      }
    }
  yy507:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy504;
        if (yych <= '\r')
          goto yy514;
        goto yy504;
      } else {
        if (yych <= ' ')
          goto yy514;
        if (yych == '-')
          goto yy507;
        goto yy504;
      }
    } else {
      if (yych <= '@') {
        if (yych <= '9')
          goto yy507;
        if (yych == '>')
          goto yy512;
        goto yy504;
      } else {
        if (yych <= 'Z')
          goto yy507;
        if (yych <= '`')
          goto yy504;
        if (yych <= 'z')
          goto yy507;
        goto yy504;
      }
    }
  yy509:
    yych = *++p;
    if (yybm[0 + yych] & 2) {
      goto yy509;
    }
    if (yych <= '>') {
      if (yych <= '9') {
        if (yych != '/')
          goto yy504;
      } else {
        if (yych <= ':')
          goto yy516;
        if (yych <= '=')
          goto yy504;
        goto yy512;
      }
    } else {
      if (yych <= '^') {
        if (yych <= '@')
          goto yy504;
        if (yych <= 'Z')
          goto yy516;
        goto yy504;
      } else {
        if (yych == '`')
          goto yy504;
        if (yych <= 'z')
          goto yy516;
        goto yy504;
      }
    }
  yy511:
    yych = *++p;
    if (yych != '>')
      goto yy504;
  yy512:
    yych = *++p;
    if (yybm[0 + yych] & 4) {
      goto yy512;
    }
    if (yych <= 0x08)
      goto yy504;
    if (yych <= '\n')
      goto yy518;
    if (yych <= '\v')
      goto yy504;
    if (yych <= '\r')
      goto yy521;
    goto yy504;
  yy514:
    yych = *++p;
    if (yych <= 0x1F) {
      if (yych <= 0x08)
        goto yy504;
      if (yych <= '\r')
        goto yy514;
      goto yy504;
    } else {
      if (yych <= ' ')
        goto yy514;
      if (yych == '>')
        goto yy512;
      goto yy504;
    }
  yy516:
    yych = *++p;
    if (yybm[0 + yych] & 8) {
      goto yy516;
    }
    if (yych <= ',') {
      if (yych <= '\r') {
        if (yych <= 0x08)
          goto yy504;
        goto yy522;
      } else {
        if (yych == ' ')
          goto yy522;
        goto yy504;
      }
    } else {
      if (yych <= '<') {
        if (yych <= '/')
          goto yy511;
        goto yy504;
      } else {
        if (yych <= '=')
          goto yy524;
        if (yych <= '>')
          goto yy512;
        goto yy504;
      }
    }
  yy518:
    yyaccept = 1;
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 4) {
      goto yy512;
    }
    if (yych <= 0x08)
      goto yy520;
    if (yych <= '\n')
      goto yy518;
    if (yych <= '\v')
      goto yy520;
    if (yych <= '\r')
      goto yy521;
  yy520 : { return 7; }
  yy521:
    ++p;
    goto yy520;
  yy522:
    yych = *++p;
    if (yych <= '<') {
      if (yych <= ' ') {
        if (yych <= 0x08)
          goto yy504;
        if (yych <= '\r')
          goto yy522;
        if (yych <= 0x1F)
          goto yy504;
        goto yy522;
      } else {
        if (yych <= '/') {
          if (yych <= '.')
            goto yy504;
          goto yy511;
        } else {
          if (yych == ':')
            goto yy516;
          goto yy504;
        }
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '=')
          goto yy524;
        if (yych <= '>')
          goto yy512;
        if (yych <= '@')
          goto yy504;
        goto yy516;
      } else {
        if (yych <= '_') {
          if (yych <= '^')
            goto yy504;
          goto yy516;
        } else {
          if (yych <= '`')
            goto yy504;
          if (yych <= 'z')
            goto yy516;
          goto yy504;
        }
      }
    }
  yy524:
    yych = *++p;
    if (yybm[0 + yych] & 32) {
      goto yy526;
    }
    if (yych <= 0xE0) {
      if (yych <= '"') {
        if (yych <= 0x00)
          goto yy504;
        if (yych <= ' ')
          goto yy524;
        goto yy528;
      } else {
        if (yych <= '\'')
          goto yy530;
        if (yych <= 0xC1)
          goto yy504;
        if (yych <= 0xDF)
          goto yy532;
        goto yy533;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy535;
        goto yy534;
      } else {
        if (yych <= 0xF0)
          goto yy536;
        if (yych <= 0xF3)
          goto yy537;
        if (yych <= 0xF4)
          goto yy538;
        goto yy504;
      }
    }
  yy526:
    yych = *++p;
    if (yybm[0 + yych] & 32) {
      goto yy526;
    }
    if (yych <= 0xE0) {
      if (yych <= '=') {
        if (yych <= 0x00)
          goto yy504;
        if (yych <= ' ')
          goto yy509;
        goto yy504;
      } else {
        if (yych <= '>')
          goto yy512;
        if (yych <= 0xC1)
          goto yy504;
        if (yych <= 0xDF)
          goto yy532;
        goto yy533;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy535;
        goto yy534;
      } else {
        if (yych <= 0xF0)
          goto yy536;
        if (yych <= 0xF3)
          goto yy537;
        if (yych <= 0xF4)
          goto yy538;
        goto yy504;
      }
    }
  yy528:
    yych = *++p;
    if (yybm[0 + yych] & 64) {
      goto yy528;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy504;
        if (yych <= '"')
          goto yy539;
        goto yy504;
      } else {
        if (yych <= 0xDF)
          goto yy540;
        if (yych <= 0xE0)
          goto yy541;
        goto yy542;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy543;
        if (yych <= 0xEF)
          goto yy542;
        goto yy544;
      } else {
        if (yych <= 0xF3)
          goto yy545;
        if (yych <= 0xF4)
          goto yy546;
        goto yy504;
      }
    }
  yy530:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy530;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy504;
        if (yych <= '\'')
          goto yy539;
        goto yy504;
      } else {
        if (yych <= 0xDF)
          goto yy547;
        if (yych <= 0xE0)
          goto yy548;
        goto yy549;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy550;
        if (yych <= 0xEF)
          goto yy549;
        goto yy551;
      } else {
        if (yych <= 0xF3)
          goto yy552;
        if (yych <= 0xF4)
          goto yy553;
        goto yy504;
      }
    }
  yy532:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy526;
    goto yy504;
  yy533:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy532;
    goto yy504;
  yy534:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy532;
    goto yy504;
  yy535:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0x9F)
      goto yy532;
    goto yy504;
  yy536:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy534;
    goto yy504;
  yy537:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy534;
    goto yy504;
  yy538:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0x8F)
      goto yy534;
    goto yy504;
  yy539:
    yych = *++p;
    if (yybm[0 + yych] & 2) {
      goto yy509;
    }
    if (yych == '/')
      goto yy511;
    if (yych == '>')
      goto yy512;
    goto yy504;
  yy540:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy528;
    goto yy504;
  yy541:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy540;
    goto yy504;
  yy542:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy540;
    goto yy504;
  yy543:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0x9F)
      goto yy540;
    goto yy504;
  yy544:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy542;
    goto yy504;
  yy545:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy542;
    goto yy504;
  yy546:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0x8F)
      goto yy542;
    goto yy504;
  yy547:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy530;
    goto yy504;
  yy548:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy547;
    goto yy504;
  yy549:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy547;
    goto yy504;
  yy550:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0x9F)
      goto yy547;
    goto yy504;
  yy551:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy549;
    goto yy504;
  yy552:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy549;
    goto yy504;
  yy553:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0x8F)
      goto yy549;
    goto yy504;
  }
}

// Try to match an HTML block end line of type 1
bufsize_t _scan_html_block_end_1(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,  64, 64, 64, 64, 64, 64,  64, 64, 64, 0,  64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 128, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,
    };
    yych = *p;
    if (yych <= 0xDF) {
      if (yych <= ';') {
        if (yych <= 0x00)
          goto yy556;
        if (yych != '\n')
          goto yy558;
      } else {
        if (yych <= '<')
          goto yy559;
        if (yych <= 0x7F)
          goto yy558;
        if (yych >= 0xC2)
          goto yy560;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy561;
        if (yych == 0xED)
          goto yy563;
        goto yy562;
      } else {
        if (yych <= 0xF0)
          goto yy564;
        if (yych <= 0xF3)
          goto yy565;
        if (yych <= 0xF4)
          goto yy566;
      }
    }
  yy556:
    ++p;
  yy557 : { return 0; }
  yy558:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy557;
      if (yych <= '\t')
        goto yy568;
      goto yy557;
    } else {
      if (yych <= 0x7F)
        goto yy568;
      if (yych <= 0xC1)
        goto yy557;
      if (yych <= 0xF4)
        goto yy568;
      goto yy557;
    }
  yy559:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '.') {
      if (yych <= 0x00)
        goto yy557;
      if (yych == '\n')
        goto yy557;
      goto yy568;
    } else {
      if (yych <= 0x7F) {
        if (yych <= '/')
          goto yy579;
        goto yy568;
      } else {
        if (yych <= 0xC1)
          goto yy557;
        if (yych <= 0xF4)
          goto yy568;
        goto yy557;
      }
    }
  yy560:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy557;
    if (yych <= 0xBF)
      goto yy567;
    goto yy557;
  yy561:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x9F)
      goto yy557;
    if (yych <= 0xBF)
      goto yy572;
    goto yy557;
  yy562:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy557;
    if (yych <= 0xBF)
      goto yy572;
    goto yy557;
  yy563:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy557;
    if (yych <= 0x9F)
      goto yy572;
    goto yy557;
  yy564:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x8F)
      goto yy557;
    if (yych <= 0xBF)
      goto yy574;
    goto yy557;
  yy565:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy557;
    if (yych <= 0xBF)
      goto yy574;
    goto yy557;
  yy566:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy557;
    if (yych <= 0x8F)
      goto yy574;
    goto yy557;
  yy567:
    yych = *++p;
  yy568:
    if (yybm[0 + yych] & 64) {
      goto yy567;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy569;
        if (yych <= '<')
          goto yy570;
      } else {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        goto yy574;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy575;
        if (yych <= 0xEF)
          goto yy574;
        goto yy576;
      } else {
        if (yych <= 0xF3)
          goto yy577;
        if (yych <= 0xF4)
          goto yy578;
      }
    }
  yy569:
    p = marker;
    if (yyaccept == 0) {
      goto yy557;
    } else {
      goto yy592;
    }
  yy570:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xDF) {
      if (yych <= '.') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= '/')
          goto yy579;
        if (yych <= 0x7F)
          goto yy567;
        if (yych <= 0xC1)
          goto yy569;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy573;
        if (yych == 0xED)
          goto yy575;
        goto yy574;
      } else {
        if (yych <= 0xF0)
          goto yy576;
        if (yych <= 0xF3)
          goto yy577;
        if (yych <= 0xF4)
          goto yy578;
        goto yy569;
      }
    }
  yy572:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy569;
    if (yych <= 0xBF)
      goto yy567;
    goto yy569;
  yy573:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy569;
    if (yych <= 0xBF)
      goto yy572;
    goto yy569;
  yy574:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy569;
    if (yych <= 0xBF)
      goto yy572;
    goto yy569;
  yy575:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy569;
    if (yych <= 0x9F)
      goto yy572;
    goto yy569;
  yy576:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy569;
    if (yych <= 0xBF)
      goto yy574;
    goto yy569;
  yy577:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy569;
    if (yych <= 0xBF)
      goto yy574;
    goto yy569;
  yy578:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy569;
    if (yych <= 0x8F)
      goto yy574;
    goto yy569;
  yy579:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 's') {
      if (yych <= 'R') {
        if (yych <= '\n') {
          if (yych <= 0x00)
            goto yy569;
          if (yych <= '\t')
            goto yy567;
          goto yy569;
        } else {
          if (yych != 'P')
            goto yy567;
        }
      } else {
        if (yych <= 'o') {
          if (yych <= 'S')
            goto yy581;
          if (yych <= 'T')
            goto yy582;
          goto yy567;
        } else {
          if (yych <= 'p')
            goto yy580;
          if (yych <= 'r')
            goto yy567;
          goto yy581;
        }
      }
    } else {
      if (yych <= 0xEC) {
        if (yych <= 0xC1) {
          if (yych <= 't')
            goto yy582;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        } else {
          if (yych <= 0xDF)
            goto yy572;
          if (yych <= 0xE0)
            goto yy573;
          goto yy574;
        }
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xED)
            goto yy575;
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy580:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= 'Q') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= 'q') {
          if (yych <= 'R')
            goto yy583;
          goto yy567;
        } else {
          if (yych <= 'r')
            goto yy583;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy581:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 't') {
      if (yych <= 'C') {
        if (yych <= '\t') {
          if (yych <= 0x00)
            goto yy569;
          goto yy567;
        } else {
          if (yych <= '\n')
            goto yy569;
          if (yych <= 'B')
            goto yy567;
          goto yy584;
        }
      } else {
        if (yych <= 'b') {
          if (yych == 'T')
            goto yy585;
          goto yy567;
        } else {
          if (yych <= 'c')
            goto yy584;
          if (yych <= 's')
            goto yy567;
          goto yy585;
        }
      }
    } else {
      if (yych <= 0xEC) {
        if (yych <= 0xC1) {
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        } else {
          if (yych <= 0xDF)
            goto yy572;
          if (yych <= 0xE0)
            goto yy573;
          goto yy574;
        }
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xED)
            goto yy575;
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy582:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= 'D') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= 'd') {
          if (yych <= 'E')
            goto yy586;
          goto yy567;
        } else {
          if (yych <= 'e')
            goto yy586;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy583:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= 'D') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= 'd') {
          if (yych <= 'E')
            goto yy587;
          goto yy567;
        } else {
          if (yych <= 'e')
            goto yy587;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy584:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= 'Q') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= 'q') {
          if (yych <= 'R')
            goto yy588;
          goto yy567;
        } else {
          if (yych <= 'r')
            goto yy588;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy585:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= 'X') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= 'x') {
          if (yych <= 'Y')
            goto yy589;
          goto yy567;
        } else {
          if (yych <= 'y')
            goto yy589;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy586:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= 'W') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= 'w') {
          if (yych <= 'X')
            goto yy590;
          goto yy567;
        } else {
          if (yych <= 'x')
            goto yy590;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy587:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xDF) {
      if (yych <= '=') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= '>')
          goto yy591;
        if (yych <= 0x7F)
          goto yy567;
        if (yych <= 0xC1)
          goto yy569;
        goto yy572;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy573;
        if (yych == 0xED)
          goto yy575;
        goto yy574;
      } else {
        if (yych <= 0xF0)
          goto yy576;
        if (yych <= 0xF3)
          goto yy577;
        if (yych <= 0xF4)
          goto yy578;
        goto yy569;
      }
    }
  yy588:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= 'H') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= 'h') {
          if (yych <= 'I')
            goto yy593;
          goto yy567;
        } else {
          if (yych <= 'i')
            goto yy593;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy589:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= 'K') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= 'k') {
          if (yych <= 'L')
            goto yy583;
          goto yy567;
        } else {
          if (yych <= 'l')
            goto yy583;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy590:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= 'S') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= 's') {
          if (yych <= 'T')
            goto yy594;
          goto yy567;
        } else {
          if (yych <= 't')
            goto yy594;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy591:
    yyaccept = 1;
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 64) {
      goto yy567;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy592;
        if (yych <= '<')
          goto yy570;
      } else {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        goto yy574;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy575;
        if (yych <= 0xEF)
          goto yy574;
        goto yy576;
      } else {
        if (yych <= 0xF3)
          goto yy577;
        if (yych <= 0xF4)
          goto yy578;
      }
    }
  yy592 : { return (bufsize_t)(p - start); }
  yy593:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= 'O') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= 'o') {
          if (yych <= 'P')
            goto yy595;
          goto yy567;
        } else {
          if (yych <= 'p')
            goto yy595;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy594:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= '@') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= '`') {
          if (yych <= 'A')
            goto yy596;
          goto yy567;
        } else {
          if (yych <= 'a')
            goto yy596;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy595:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= 'S') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= 's') {
          if (yych <= 'T')
            goto yy587;
          goto yy567;
        } else {
          if (yych <= 't')
            goto yy587;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy596:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= 'Q') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= 'q') {
          if (yych >= 'S')
            goto yy567;
        } else {
          if (yych <= 'r')
            goto yy597;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy597:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= 'D') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= 'd') {
          if (yych >= 'F')
            goto yy567;
        } else {
          if (yych <= 'e')
            goto yy598;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  yy598:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy570;
    }
    if (yych <= 0xC1) {
      if (yych <= '@') {
        if (yych <= 0x00)
          goto yy569;
        if (yych == '\n')
          goto yy569;
        goto yy567;
      } else {
        if (yych <= '`') {
          if (yych <= 'A')
            goto yy587;
          goto yy567;
        } else {
          if (yych <= 'a')
            goto yy587;
          if (yych <= 0x7F)
            goto yy567;
          goto yy569;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy572;
        if (yych <= 0xE0)
          goto yy573;
        if (yych <= 0xEC)
          goto yy574;
        goto yy575;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy574;
          goto yy576;
        } else {
          if (yych <= 0xF3)
            goto yy577;
          if (yych <= 0xF4)
            goto yy578;
          goto yy569;
        }
      }
    }
  }
}

// Try to match an HTML block end line of type 2
bufsize_t _scan_html_block_end_2(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,  64, 64, 64, 64, 64, 64, 64, 64, 64,  0,  64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 128, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,
    };
    yych = *p;
    if (yych <= 0xDF) {
      if (yych <= ',') {
        if (yych <= 0x00)
          goto yy601;
        if (yych != '\n')
          goto yy603;
      } else {
        if (yych <= '-')
          goto yy604;
        if (yych <= 0x7F)
          goto yy603;
        if (yych >= 0xC2)
          goto yy605;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy606;
        if (yych == 0xED)
          goto yy608;
        goto yy607;
      } else {
        if (yych <= 0xF0)
          goto yy609;
        if (yych <= 0xF3)
          goto yy610;
        if (yych <= 0xF4)
          goto yy611;
      }
    }
  yy601:
    ++p;
  yy602 : { return 0; }
  yy603:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy602;
      if (yych <= '\t')
        goto yy613;
      goto yy602;
    } else {
      if (yych <= 0x7F)
        goto yy613;
      if (yych <= 0xC1)
        goto yy602;
      if (yych <= 0xF4)
        goto yy613;
      goto yy602;
    }
  yy604:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 128) {
      goto yy623;
    }
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy602;
      if (yych <= '\t')
        goto yy613;
      goto yy602;
    } else {
      if (yych <= 0x7F)
        goto yy613;
      if (yych <= 0xC1)
        goto yy602;
      if (yych <= 0xF4)
        goto yy613;
      goto yy602;
    }
  yy605:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy602;
    if (yych <= 0xBF)
      goto yy612;
    goto yy602;
  yy606:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x9F)
      goto yy602;
    if (yych <= 0xBF)
      goto yy616;
    goto yy602;
  yy607:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy602;
    if (yych <= 0xBF)
      goto yy616;
    goto yy602;
  yy608:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy602;
    if (yych <= 0x9F)
      goto yy616;
    goto yy602;
  yy609:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x8F)
      goto yy602;
    if (yych <= 0xBF)
      goto yy618;
    goto yy602;
  yy610:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy602;
    if (yych <= 0xBF)
      goto yy618;
    goto yy602;
  yy611:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy602;
    if (yych <= 0x8F)
      goto yy618;
    goto yy602;
  yy612:
    yych = *++p;
  yy613:
    if (yybm[0 + yych] & 64) {
      goto yy612;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy614;
        if (yych <= '-')
          goto yy615;
      } else {
        if (yych <= 0xDF)
          goto yy616;
        if (yych <= 0xE0)
          goto yy617;
        goto yy618;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy619;
        if (yych <= 0xEF)
          goto yy618;
        goto yy620;
      } else {
        if (yych <= 0xF3)
          goto yy621;
        if (yych <= 0xF4)
          goto yy622;
      }
    }
  yy614:
    p = marker;
    if (yyaccept == 0) {
      goto yy602;
    } else {
      goto yy626;
    }
  yy615:
    yych = *++p;
    if (yybm[0 + yych] & 64) {
      goto yy612;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy614;
        if (yych <= '-')
          goto yy623;
        goto yy614;
      } else {
        if (yych <= 0xDF)
          goto yy616;
        if (yych <= 0xE0)
          goto yy617;
        goto yy618;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy619;
        if (yych <= 0xEF)
          goto yy618;
        goto yy620;
      } else {
        if (yych <= 0xF3)
          goto yy621;
        if (yych <= 0xF4)
          goto yy622;
        goto yy614;
      }
    }
  yy616:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy614;
    if (yych <= 0xBF)
      goto yy612;
    goto yy614;
  yy617:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy614;
    if (yych <= 0xBF)
      goto yy616;
    goto yy614;
  yy618:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy614;
    if (yych <= 0xBF)
      goto yy616;
    goto yy614;
  yy619:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy614;
    if (yych <= 0x9F)
      goto yy616;
    goto yy614;
  yy620:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy614;
    if (yych <= 0xBF)
      goto yy618;
    goto yy614;
  yy621:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy614;
    if (yych <= 0xBF)
      goto yy618;
    goto yy614;
  yy622:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy614;
    if (yych <= 0x8F)
      goto yy618;
    goto yy614;
  yy623:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy623;
    }
    if (yych <= 0xDF) {
      if (yych <= '=') {
        if (yych <= 0x00)
          goto yy614;
        if (yych == '\n')
          goto yy614;
        goto yy612;
      } else {
        if (yych <= '>')
          goto yy625;
        if (yych <= 0x7F)
          goto yy612;
        if (yych <= 0xC1)
          goto yy614;
        goto yy616;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy617;
        if (yych == 0xED)
          goto yy619;
        goto yy618;
      } else {
        if (yych <= 0xF0)
          goto yy620;
        if (yych <= 0xF3)
          goto yy621;
        if (yych <= 0xF4)
          goto yy622;
        goto yy614;
      }
    }
  yy625:
    yyaccept = 1;
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 64) {
      goto yy612;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy626;
        if (yych <= '-')
          goto yy615;
      } else {
        if (yych <= 0xDF)
          goto yy616;
        if (yych <= 0xE0)
          goto yy617;
        goto yy618;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy619;
        if (yych <= 0xEF)
          goto yy618;
        goto yy620;
      } else {
        if (yych <= 0xF3)
          goto yy621;
        if (yych <= 0xF4)
          goto yy622;
      }
    }
  yy626 : { return (bufsize_t)(p - start); }
  }
}

// Try to match an HTML block end line of type 3
bufsize_t _scan_html_block_end_3(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,  64, 64, 64, 64, 64, 64, 64, 64, 64,  0,  64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 128, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,
    };
    yych = *p;
    if (yych <= 0xDF) {
      if (yych <= '>') {
        if (yych <= 0x00)
          goto yy629;
        if (yych != '\n')
          goto yy631;
      } else {
        if (yych <= '?')
          goto yy632;
        if (yych <= 0x7F)
          goto yy631;
        if (yych >= 0xC2)
          goto yy633;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy634;
        if (yych == 0xED)
          goto yy636;
        goto yy635;
      } else {
        if (yych <= 0xF0)
          goto yy637;
        if (yych <= 0xF3)
          goto yy638;
        if (yych <= 0xF4)
          goto yy639;
      }
    }
  yy629:
    ++p;
  yy630 : { return 0; }
  yy631:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy630;
      if (yych <= '\t')
        goto yy641;
      goto yy630;
    } else {
      if (yych <= 0x7F)
        goto yy641;
      if (yych <= 0xC1)
        goto yy630;
      if (yych <= 0xF4)
        goto yy641;
      goto yy630;
    }
  yy632:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '=') {
      if (yych <= 0x00)
        goto yy630;
      if (yych == '\n')
        goto yy630;
      goto yy641;
    } else {
      if (yych <= 0x7F) {
        if (yych <= '>')
          goto yy652;
        goto yy641;
      } else {
        if (yych <= 0xC1)
          goto yy630;
        if (yych <= 0xF4)
          goto yy641;
        goto yy630;
      }
    }
  yy633:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy630;
    if (yych <= 0xBF)
      goto yy640;
    goto yy630;
  yy634:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x9F)
      goto yy630;
    if (yych <= 0xBF)
      goto yy645;
    goto yy630;
  yy635:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy630;
    if (yych <= 0xBF)
      goto yy645;
    goto yy630;
  yy636:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy630;
    if (yych <= 0x9F)
      goto yy645;
    goto yy630;
  yy637:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x8F)
      goto yy630;
    if (yych <= 0xBF)
      goto yy647;
    goto yy630;
  yy638:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy630;
    if (yych <= 0xBF)
      goto yy647;
    goto yy630;
  yy639:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy630;
    if (yych <= 0x8F)
      goto yy647;
    goto yy630;
  yy640:
    yych = *++p;
  yy641:
    if (yybm[0 + yych] & 64) {
      goto yy640;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy642;
        if (yych <= '?')
          goto yy643;
      } else {
        if (yych <= 0xDF)
          goto yy645;
        if (yych <= 0xE0)
          goto yy646;
        goto yy647;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy648;
        if (yych <= 0xEF)
          goto yy647;
        goto yy649;
      } else {
        if (yych <= 0xF3)
          goto yy650;
        if (yych <= 0xF4)
          goto yy651;
      }
    }
  yy642:
    p = marker;
    if (yyaccept == 0) {
      goto yy630;
    } else {
      goto yy653;
    }
  yy643:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy643;
    }
    if (yych <= 0xDF) {
      if (yych <= '=') {
        if (yych <= 0x00)
          goto yy642;
        if (yych == '\n')
          goto yy642;
        goto yy640;
      } else {
        if (yych <= '>')
          goto yy652;
        if (yych <= 0x7F)
          goto yy640;
        if (yych <= 0xC1)
          goto yy642;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy646;
        if (yych == 0xED)
          goto yy648;
        goto yy647;
      } else {
        if (yych <= 0xF0)
          goto yy649;
        if (yych <= 0xF3)
          goto yy650;
        if (yych <= 0xF4)
          goto yy651;
        goto yy642;
      }
    }
  yy645:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy642;
    if (yych <= 0xBF)
      goto yy640;
    goto yy642;
  yy646:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy642;
    if (yych <= 0xBF)
      goto yy645;
    goto yy642;
  yy647:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy642;
    if (yych <= 0xBF)
      goto yy645;
    goto yy642;
  yy648:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy642;
    if (yych <= 0x9F)
      goto yy645;
    goto yy642;
  yy649:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy642;
    if (yych <= 0xBF)
      goto yy647;
    goto yy642;
  yy650:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy642;
    if (yych <= 0xBF)
      goto yy647;
    goto yy642;
  yy651:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy642;
    if (yych <= 0x8F)
      goto yy647;
    goto yy642;
  yy652:
    yyaccept = 1;
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 64) {
      goto yy640;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy653;
        if (yych <= '?')
          goto yy643;
      } else {
        if (yych <= 0xDF)
          goto yy645;
        if (yych <= 0xE0)
          goto yy646;
        goto yy647;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy648;
        if (yych <= 0xEF)
          goto yy647;
        goto yy649;
      } else {
        if (yych <= 0xF3)
          goto yy650;
        if (yych <= 0xF4)
          goto yy651;
      }
    }
  yy653 : { return (bufsize_t)(p - start); }
  }
}

// Try to match an HTML block end line of type 4
bufsize_t _scan_html_block_end_4(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,   128, 128, 128, 128, 128, 128, 128, 128, 128, 0,   128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 64,  128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,
    };
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy659;
    }
    if (yych <= 0xE0) {
      if (yych <= '\n') {
        if (yych <= 0x00)
          goto yy656;
        if (yych <= '\t')
          goto yy658;
      } else {
        if (yych <= 0x7F)
          goto yy658;
        if (yych <= 0xC1)
          goto yy656;
        if (yych <= 0xDF)
          goto yy662;
        goto yy663;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy665;
        goto yy664;
      } else {
        if (yych <= 0xF0)
          goto yy666;
        if (yych <= 0xF3)
          goto yy667;
        if (yych <= 0xF4)
          goto yy668;
      }
    }
  yy656:
    ++p;
  yy657 : { return 0; }
  yy658:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy657;
      if (yych <= '\t')
        goto yy670;
      goto yy657;
    } else {
      if (yych <= 0x7F)
        goto yy670;
      if (yych <= 0xC1)
        goto yy657;
      if (yych <= 0xF4)
        goto yy670;
      goto yy657;
    }
  yy659:
    yyaccept = 1;
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 128) {
      goto yy669;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy661;
        if (yych <= '>')
          goto yy659;
      } else {
        if (yych <= 0xDF)
          goto yy672;
        if (yych <= 0xE0)
          goto yy673;
        goto yy674;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy675;
        if (yych <= 0xEF)
          goto yy674;
        goto yy676;
      } else {
        if (yych <= 0xF3)
          goto yy677;
        if (yych <= 0xF4)
          goto yy678;
      }
    }
  yy661 : { return (bufsize_t)(p - start); }
  yy662:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy657;
    if (yych <= 0xBF)
      goto yy669;
    goto yy657;
  yy663:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x9F)
      goto yy657;
    if (yych <= 0xBF)
      goto yy672;
    goto yy657;
  yy664:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy657;
    if (yych <= 0xBF)
      goto yy672;
    goto yy657;
  yy665:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy657;
    if (yych <= 0x9F)
      goto yy672;
    goto yy657;
  yy666:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x8F)
      goto yy657;
    if (yych <= 0xBF)
      goto yy674;
    goto yy657;
  yy667:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy657;
    if (yych <= 0xBF)
      goto yy674;
    goto yy657;
  yy668:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy657;
    if (yych <= 0x8F)
      goto yy674;
    goto yy657;
  yy669:
    yych = *++p;
  yy670:
    if (yybm[0 + yych] & 128) {
      goto yy669;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy671;
        if (yych <= '>')
          goto yy659;
      } else {
        if (yych <= 0xDF)
          goto yy672;
        if (yych <= 0xE0)
          goto yy673;
        goto yy674;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy675;
        if (yych <= 0xEF)
          goto yy674;
        goto yy676;
      } else {
        if (yych <= 0xF3)
          goto yy677;
        if (yych <= 0xF4)
          goto yy678;
      }
    }
  yy671:
    p = marker;
    if (yyaccept == 0) {
      goto yy657;
    } else {
      goto yy661;
    }
  yy672:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy671;
    if (yych <= 0xBF)
      goto yy669;
    goto yy671;
  yy673:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy671;
    if (yych <= 0xBF)
      goto yy672;
    goto yy671;
  yy674:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy671;
    if (yych <= 0xBF)
      goto yy672;
    goto yy671;
  yy675:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy671;
    if (yych <= 0x9F)
      goto yy672;
    goto yy671;
  yy676:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy671;
    if (yych <= 0xBF)
      goto yy674;
    goto yy671;
  yy677:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy671;
    if (yych <= 0xBF)
      goto yy674;
    goto yy671;
  yy678:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy671;
    if (yych <= 0x8F)
      goto yy674;
    goto yy671;
  }
}

// Try to match an HTML block end line of type 5
bufsize_t _scan_html_block_end_5(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,  64, 64, 64,  64, 64, 64, 64, 64, 64, 0,  64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 128, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,
    };
    yych = *p;
    if (yych <= 0xDF) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy681;
        if (yych != '\n')
          goto yy683;
      } else {
        if (yych <= ']')
          goto yy684;
        if (yych <= 0x7F)
          goto yy683;
        if (yych >= 0xC2)
          goto yy685;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy686;
        if (yych == 0xED)
          goto yy688;
        goto yy687;
      } else {
        if (yych <= 0xF0)
          goto yy689;
        if (yych <= 0xF3)
          goto yy690;
        if (yych <= 0xF4)
          goto yy691;
      }
    }
  yy681:
    ++p;
  yy682 : { return 0; }
  yy683:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy682;
      if (yych <= '\t')
        goto yy693;
      goto yy682;
    } else {
      if (yych <= 0x7F)
        goto yy693;
      if (yych <= 0xC1)
        goto yy682;
      if (yych <= 0xF4)
        goto yy693;
      goto yy682;
    }
  yy684:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 128) {
      goto yy703;
    }
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy682;
      if (yych <= '\t')
        goto yy693;
      goto yy682;
    } else {
      if (yych <= 0x7F)
        goto yy693;
      if (yych <= 0xC1)
        goto yy682;
      if (yych <= 0xF4)
        goto yy693;
      goto yy682;
    }
  yy685:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy682;
    if (yych <= 0xBF)
      goto yy692;
    goto yy682;
  yy686:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x9F)
      goto yy682;
    if (yych <= 0xBF)
      goto yy696;
    goto yy682;
  yy687:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy682;
    if (yych <= 0xBF)
      goto yy696;
    goto yy682;
  yy688:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy682;
    if (yych <= 0x9F)
      goto yy696;
    goto yy682;
  yy689:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x8F)
      goto yy682;
    if (yych <= 0xBF)
      goto yy698;
    goto yy682;
  yy690:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy682;
    if (yych <= 0xBF)
      goto yy698;
    goto yy682;
  yy691:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy682;
    if (yych <= 0x8F)
      goto yy698;
    goto yy682;
  yy692:
    yych = *++p;
  yy693:
    if (yybm[0 + yych] & 64) {
      goto yy692;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy694;
        if (yych <= ']')
          goto yy695;
      } else {
        if (yych <= 0xDF)
          goto yy696;
        if (yych <= 0xE0)
          goto yy697;
        goto yy698;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy699;
        if (yych <= 0xEF)
          goto yy698;
        goto yy700;
      } else {
        if (yych <= 0xF3)
          goto yy701;
        if (yych <= 0xF4)
          goto yy702;
      }
    }
  yy694:
    p = marker;
    if (yyaccept == 0) {
      goto yy682;
    } else {
      goto yy706;
    }
  yy695:
    yych = *++p;
    if (yybm[0 + yych] & 64) {
      goto yy692;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy694;
        if (yych <= ']')
          goto yy703;
        goto yy694;
      } else {
        if (yych <= 0xDF)
          goto yy696;
        if (yych <= 0xE0)
          goto yy697;
        goto yy698;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy699;
        if (yych <= 0xEF)
          goto yy698;
        goto yy700;
      } else {
        if (yych <= 0xF3)
          goto yy701;
        if (yych <= 0xF4)
          goto yy702;
        goto yy694;
      }
    }
  yy696:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy694;
    if (yych <= 0xBF)
      goto yy692;
    goto yy694;
  yy697:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy694;
    if (yych <= 0xBF)
      goto yy696;
    goto yy694;
  yy698:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy694;
    if (yych <= 0xBF)
      goto yy696;
    goto yy694;
  yy699:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy694;
    if (yych <= 0x9F)
      goto yy696;
    goto yy694;
  yy700:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy694;
    if (yych <= 0xBF)
      goto yy698;
    goto yy694;
  yy701:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy694;
    if (yych <= 0xBF)
      goto yy698;
    goto yy694;
  yy702:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy694;
    if (yych <= 0x8F)
      goto yy698;
    goto yy694;
  yy703:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy703;
    }
    if (yych <= 0xDF) {
      if (yych <= '=') {
        if (yych <= 0x00)
          goto yy694;
        if (yych == '\n')
          goto yy694;
        goto yy692;
      } else {
        if (yych <= '>')
          goto yy705;
        if (yych <= 0x7F)
          goto yy692;
        if (yych <= 0xC1)
          goto yy694;
        goto yy696;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy697;
        if (yych == 0xED)
          goto yy699;
        goto yy698;
      } else {
        if (yych <= 0xF0)
          goto yy700;
        if (yych <= 0xF3)
          goto yy701;
        if (yych <= 0xF4)
          goto yy702;
        goto yy694;
      }
    }
  yy705:
    yyaccept = 1;
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 64) {
      goto yy692;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy706;
        if (yych <= ']')
          goto yy695;
      } else {
        if (yych <= 0xDF)
          goto yy696;
        if (yych <= 0xE0)
          goto yy697;
        goto yy698;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy699;
        if (yych <= 0xEF)
          goto yy698;
        goto yy700;
      } else {
        if (yych <= 0xF3)
          goto yy701;
        if (yych <= 0xF4)
          goto yy702;
      }
    }
  yy706 : { return (bufsize_t)(p - start); }
  }
}

// Try to match a link title (in single quotes, in double quotes, or
// in parentheses), returning number of chars matched.  Allow one
// level of internal nesting (quotes within quotes).
bufsize_t _scan_link_title(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,   208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208,
        208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208,
        208, 208, 208, 208, 208, 208, 192, 208, 208, 208, 208, 144, 80,  80,
        208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208,
        208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208,
        208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208,
        208, 208, 208, 208, 208, 208, 208, 208, 32,  208, 208, 208, 208, 208,
        208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208,
        208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208, 208,
        208, 208, 0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,
    };
    yych = *p;
    if (yych <= '&') {
      if (yych == '"')
        goto yy711;
    } else {
      if (yych <= '\'')
        goto yy712;
      if (yych <= '(')
        goto yy713;
    }
    ++p;
  yy710 : { return 0; }
  yy711:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x00)
      goto yy710;
    if (yych <= 0x7F)
      goto yy715;
    if (yych <= 0xC1)
      goto yy710;
    if (yych <= 0xF4)
      goto yy715;
    goto yy710;
  yy712:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x00)
      goto yy710;
    if (yych <= 0x7F)
      goto yy729;
    if (yych <= 0xC1)
      goto yy710;
    if (yych <= 0xF4)
      goto yy729;
    goto yy710;
  yy713:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '(') {
      if (yych <= 0x00)
        goto yy710;
      if (yych <= '\'')
        goto yy742;
      goto yy710;
    } else {
      if (yych <= 0x7F)
        goto yy742;
      if (yych <= 0xC1)
        goto yy710;
      if (yych <= 0xF4)
        goto yy742;
      goto yy710;
    }
  yy714:
    yych = *++p;
  yy715:
    if (yybm[0 + yych] & 16) {
      goto yy714;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy716;
        if (yych <= '"')
          goto yy717;
        goto yy719;
      } else {
        if (yych <= 0xC1)
          goto yy716;
        if (yych <= 0xDF)
          goto yy721;
        goto yy722;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy724;
        goto yy723;
      } else {
        if (yych <= 0xF0)
          goto yy725;
        if (yych <= 0xF3)
          goto yy726;
        if (yych <= 0xF4)
          goto yy727;
      }
    }
  yy716:
    p = marker;
    if (yyaccept <= 1) {
      if (yyaccept == 0) {
        goto yy710;
      } else {
        goto yy718;
      }
    } else {
      if (yyaccept == 2) {
        goto yy731;
      } else {
        goto yy744;
      }
    }
  yy717:
    ++p;
  yy718 : { return (bufsize_t)(p - start); }
  yy719:
    yych = *++p;
    if (yybm[0 + yych] & 16) {
      goto yy714;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy716;
        if (yych <= '"')
          goto yy754;
        goto yy719;
      } else {
        if (yych <= 0xC1)
          goto yy716;
        if (yych >= 0xE0)
          goto yy722;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy724;
        goto yy723;
      } else {
        if (yych <= 0xF0)
          goto yy725;
        if (yych <= 0xF3)
          goto yy726;
        if (yych <= 0xF4)
          goto yy727;
        goto yy716;
      }
    }
  yy721:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy714;
    goto yy716;
  yy722:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy721;
    goto yy716;
  yy723:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy721;
    goto yy716;
  yy724:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0x9F)
      goto yy721;
    goto yy716;
  yy725:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy723;
    goto yy716;
  yy726:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy723;
    goto yy716;
  yy727:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0x8F)
      goto yy723;
    goto yy716;
  yy728:
    yych = *++p;
  yy729:
    if (yybm[0 + yych] & 64) {
      goto yy728;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy716;
        if (yych >= '(')
          goto yy732;
      } else {
        if (yych <= 0xC1)
          goto yy716;
        if (yych <= 0xDF)
          goto yy734;
        goto yy735;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy737;
        goto yy736;
      } else {
        if (yych <= 0xF0)
          goto yy738;
        if (yych <= 0xF3)
          goto yy739;
        if (yych <= 0xF4)
          goto yy740;
        goto yy716;
      }
    }
  yy730:
    ++p;
  yy731 : { return (bufsize_t)(p - start); }
  yy732:
    yych = *++p;
    if (yybm[0 + yych] & 64) {
      goto yy728;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy716;
        if (yych <= '\'')
          goto yy755;
        goto yy732;
      } else {
        if (yych <= 0xC1)
          goto yy716;
        if (yych >= 0xE0)
          goto yy735;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy737;
        goto yy736;
      } else {
        if (yych <= 0xF0)
          goto yy738;
        if (yych <= 0xF3)
          goto yy739;
        if (yych <= 0xF4)
          goto yy740;
        goto yy716;
      }
    }
  yy734:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy728;
    goto yy716;
  yy735:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy734;
    goto yy716;
  yy736:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy734;
    goto yy716;
  yy737:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0x9F)
      goto yy734;
    goto yy716;
  yy738:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy736;
    goto yy716;
  yy739:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy736;
    goto yy716;
  yy740:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0x8F)
      goto yy736;
    goto yy716;
  yy741:
    yych = *++p;
  yy742:
    if (yybm[0 + yych] & 128) {
      goto yy741;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= '(')
          goto yy716;
        if (yych >= '*')
          goto yy745;
      } else {
        if (yych <= 0xC1)
          goto yy716;
        if (yych <= 0xDF)
          goto yy747;
        goto yy748;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy750;
        goto yy749;
      } else {
        if (yych <= 0xF0)
          goto yy751;
        if (yych <= 0xF3)
          goto yy752;
        if (yych <= 0xF4)
          goto yy753;
        goto yy716;
      }
    }
  yy743:
    ++p;
  yy744 : { return (bufsize_t)(p - start); }
  yy745:
    yych = *++p;
    if (yych <= 0xDF) {
      if (yych <= '[') {
        if (yych <= 0x00)
          goto yy716;
        if (yych == ')')
          goto yy756;
        goto yy741;
      } else {
        if (yych <= '\\')
          goto yy745;
        if (yych <= 0x7F)
          goto yy741;
        if (yych <= 0xC1)
          goto yy716;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy748;
        if (yych == 0xED)
          goto yy750;
        goto yy749;
      } else {
        if (yych <= 0xF0)
          goto yy751;
        if (yych <= 0xF3)
          goto yy752;
        if (yych <= 0xF4)
          goto yy753;
        goto yy716;
      }
    }
  yy747:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy741;
    goto yy716;
  yy748:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy747;
    goto yy716;
  yy749:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy747;
    goto yy716;
  yy750:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0x9F)
      goto yy747;
    goto yy716;
  yy751:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy749;
    goto yy716;
  yy752:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0xBF)
      goto yy749;
    goto yy716;
  yy753:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy716;
    if (yych <= 0x8F)
      goto yy749;
    goto yy716;
  yy754:
    yyaccept = 1;
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 16) {
      goto yy714;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy718;
        if (yych <= '"')
          goto yy717;
        goto yy719;
      } else {
        if (yych <= 0xC1)
          goto yy718;
        if (yych <= 0xDF)
          goto yy721;
        goto yy722;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy724;
        goto yy723;
      } else {
        if (yych <= 0xF0)
          goto yy725;
        if (yych <= 0xF3)
          goto yy726;
        if (yych <= 0xF4)
          goto yy727;
        goto yy718;
      }
    }
  yy755:
    yyaccept = 2;
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 64) {
      goto yy728;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy731;
        if (yych <= '\'')
          goto yy730;
        goto yy732;
      } else {
        if (yych <= 0xC1)
          goto yy731;
        if (yych <= 0xDF)
          goto yy734;
        goto yy735;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy737;
        goto yy736;
      } else {
        if (yych <= 0xF0)
          goto yy738;
        if (yych <= 0xF3)
          goto yy739;
        if (yych <= 0xF4)
          goto yy740;
        goto yy731;
      }
    }
  yy756:
    yyaccept = 3;
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 128) {
      goto yy741;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= '(')
          goto yy744;
        if (yych <= ')')
          goto yy743;
        goto yy745;
      } else {
        if (yych <= 0xC1)
          goto yy744;
        if (yych <= 0xDF)
          goto yy747;
        goto yy748;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy750;
        goto yy749;
      } else {
        if (yych <= 0xF0)
          goto yy751;
        if (yych <= 0xF3)
          goto yy752;
        if (yych <= 0xF4)
          goto yy753;
        goto yy744;
      }
    }
  }
}

// Match space characters, including newlines.
bufsize_t _scan_spacechars(const unsigned char *p) {
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0, 0, 0, 0, 0, 0, 0, 0, 0, 128, 128, 128, 128, 128, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   128, 0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0,
    };
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy761;
    }
    ++p;
    { return 0; }
  yy761:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy761;
    }
    { return (bufsize_t)(p - start); }
  }
}

// Match ATX heading start.
bufsize_t _scan_atx_heading_start(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0, 0, 0, 0, 0, 0, 0, 0, 0, 128, 0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   128, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0,
    };
    yych = *p;
    if (yych == '#')
      goto yy768;
    ++p;
  yy767 : { return 0; }
  yy768:
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 128) {
      goto yy769;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy767;
      if (yych <= '\n')
        goto yy772;
      goto yy767;
    } else {
      if (yych <= '\r')
        goto yy772;
      if (yych == '#')
        goto yy773;
      goto yy767;
    }
  yy769:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy769;
    }
  yy771 : { return (bufsize_t)(p - start); }
  yy772:
    ++p;
    goto yy771;
  yy773:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy769;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy774;
      if (yych <= '\n')
        goto yy772;
    } else {
      if (yych <= '\r')
        goto yy772;
      if (yych == '#')
        goto yy775;
    }
  yy774:
    p = marker;
    goto yy767;
  yy775:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy769;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy774;
      if (yych <= '\n')
        goto yy772;
      goto yy774;
    } else {
      if (yych <= '\r')
        goto yy772;
      if (yych != '#')
        goto yy774;
    }
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy769;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy774;
      if (yych <= '\n')
        goto yy772;
      goto yy774;
    } else {
      if (yych <= '\r')
        goto yy772;
      if (yych != '#')
        goto yy774;
    }
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy769;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy774;
      if (yych <= '\n')
        goto yy772;
      goto yy774;
    } else {
      if (yych <= '\r')
        goto yy772;
      if (yych != '#')
        goto yy774;
    }
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy769;
    }
    if (yych <= 0x08)
      goto yy774;
    if (yych <= '\n')
      goto yy772;
    if (yych == '\r')
      goto yy772;
    goto yy774;
  }
}

// Match setext heading line.  Return 1 for level-1 heading,
// 2 for level-2, 0 for no match.
bufsize_t _scan_setext_heading_line(const unsigned char *p) {
  const unsigned char *marker = NULL;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0, 0,  0, 0, 0, 0, 0, 0, 0, 32, 0,  0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0,
        0, 0,  0, 0, 0, 0, 0, 0, 0, 0,  32, 0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0,
        0, 64, 0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 128, 0, 0, 0, 0,
        0, 0,  0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0,
        0, 0,  0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0,
        0, 0,  0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0,
        0, 0,  0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0,
        0, 0,  0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0,
        0, 0,  0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0,
        0, 0,  0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0,
        0, 0,  0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,   0, 0, 0, 0,
        0, 0,  0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0,
    };
    yych = *p;
    if (yych == '-')
      goto yy783;
    if (yych == '=')
      goto yy784;
    ++p;
  yy782 : { return 0; }
  yy783:
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 64) {
      goto yy790;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy782;
      if (yych <= '\n')
        goto yy786;
      goto yy782;
    } else {
      if (yych <= '\r')
        goto yy786;
      if (yych == ' ')
        goto yy786;
      goto yy782;
    }
  yy784:
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 128) {
      goto yy796;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy782;
      if (yych <= '\n')
        goto yy793;
      goto yy782;
    } else {
      if (yych <= '\r')
        goto yy793;
      if (yych == ' ')
        goto yy793;
      goto yy782;
    }
  yy785:
    yych = *++p;
  yy786:
    if (yybm[0 + yych] & 32) {
      goto yy785;
    }
    if (yych <= 0x08)
      goto yy787;
    if (yych <= '\n')
      goto yy788;
    if (yych == '\r')
      goto yy788;
  yy787:
    p = marker;
    goto yy782;
  yy788:
    ++p;
    { return 2; }
  yy790:
    yych = *++p;
    if (yybm[0 + yych] & 32) {
      goto yy785;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy787;
      if (yych <= '\n')
        goto yy788;
      goto yy787;
    } else {
      if (yych <= '\r')
        goto yy788;
      if (yych == '-')
        goto yy790;
      goto yy787;
    }
  yy792:
    yych = *++p;
  yy793:
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy787;
      if (yych <= '\t')
        goto yy792;
      if (yych >= '\v')
        goto yy787;
    } else {
      if (yych <= '\r')
        goto yy794;
      if (yych == ' ')
        goto yy792;
      goto yy787;
    }
  yy794:
    ++p;
    { return 1; }
  yy796:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy796;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy787;
      if (yych <= '\t')
        goto yy792;
      if (yych <= '\n')
        goto yy794;
      goto yy787;
    } else {
      if (yych <= '\r')
        goto yy794;
      if (yych == ' ')
        goto yy792;
      goto yy787;
    }
  }
}

// Scan an opening code fence.
bufsize_t _scan_open_code_fence(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0,   192, 192, 192, 192, 192, 192, 192, 192, 192, 0,   192, 192, 0,
        192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192,
        192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192,
        192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192,
        192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192,
        192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192,
        192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 144, 192,
        192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192,
        192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192, 192,
        224, 192, 0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,
    };
    yych = *p;
    if (yych == '`')
      goto yy802;
    if (yych == '~')
      goto yy803;
    ++p;
  yy801 : { return 0; }
  yy802:
    yych = *(marker = ++p);
    if (yych == '`')
      goto yy804;
    goto yy801;
  yy803:
    yych = *(marker = ++p);
    if (yych == '~')
      goto yy806;
    goto yy801;
  yy804:
    yych = *++p;
    if (yybm[0 + yych] & 16) {
      goto yy807;
    }
  yy805:
    p = marker;
    goto yy801;
  yy806:
    yych = *++p;
    if (yybm[0 + yych] & 32) {
      goto yy809;
    }
    goto yy805;
  yy807:
    yych = *++p;
    if (yybm[0 + yych] & 16) {
      goto yy807;
    }
    if (yych <= 0xDF) {
      if (yych <= '\f') {
        if (yych <= 0x00)
          goto yy805;
        if (yych == '\n') {
          marker = p;
          goto yy813;
        }
        marker = p;
        goto yy811;
      } else {
        if (yych <= '\r') {
          marker = p;
          goto yy813;
        }
        if (yych <= 0x7F) {
          marker = p;
          goto yy811;
        }
        if (yych <= 0xC1)
          goto yy805;
        marker = p;
        goto yy815;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0) {
          marker = p;
          goto yy816;
        }
        if (yych == 0xED) {
          marker = p;
          goto yy818;
        }
        marker = p;
        goto yy817;
      } else {
        if (yych <= 0xF0) {
          marker = p;
          goto yy819;
        }
        if (yych <= 0xF3) {
          marker = p;
          goto yy820;
        }
        if (yych <= 0xF4) {
          marker = p;
          goto yy821;
        }
        goto yy805;
      }
    }
  yy809:
    yych = *++p;
    if (yybm[0 + yych] & 32) {
      goto yy809;
    }
    if (yych <= 0xDF) {
      if (yych <= '\f') {
        if (yych <= 0x00)
          goto yy805;
        if (yych == '\n') {
          marker = p;
          goto yy824;
        }
        marker = p;
        goto yy822;
      } else {
        if (yych <= '\r') {
          marker = p;
          goto yy824;
        }
        if (yych <= 0x7F) {
          marker = p;
          goto yy822;
        }
        if (yych <= 0xC1)
          goto yy805;
        marker = p;
        goto yy826;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0) {
          marker = p;
          goto yy827;
        }
        if (yych == 0xED) {
          marker = p;
          goto yy829;
        }
        marker = p;
        goto yy828;
      } else {
        if (yych <= 0xF0) {
          marker = p;
          goto yy830;
        }
        if (yych <= 0xF3) {
          marker = p;
          goto yy831;
        }
        if (yych <= 0xF4) {
          marker = p;
          goto yy832;
        }
        goto yy805;
      }
    }
  yy811:
    yych = *++p;
    if (yybm[0 + yych] & 64) {
      goto yy811;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy805;
        if (yych >= 0x0E)
          goto yy805;
      } else {
        if (yych <= 0xDF)
          goto yy815;
        if (yych <= 0xE0)
          goto yy816;
        goto yy817;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy818;
        if (yych <= 0xEF)
          goto yy817;
        goto yy819;
      } else {
        if (yych <= 0xF3)
          goto yy820;
        if (yych <= 0xF4)
          goto yy821;
        goto yy805;
      }
    }
  yy813:
    ++p;
    p = marker;
    { return (bufsize_t)(p - start); }
  yy815:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy805;
    if (yych <= 0xBF)
      goto yy811;
    goto yy805;
  yy816:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy805;
    if (yych <= 0xBF)
      goto yy815;
    goto yy805;
  yy817:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy805;
    if (yych <= 0xBF)
      goto yy815;
    goto yy805;
  yy818:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy805;
    if (yych <= 0x9F)
      goto yy815;
    goto yy805;
  yy819:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy805;
    if (yych <= 0xBF)
      goto yy817;
    goto yy805;
  yy820:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy805;
    if (yych <= 0xBF)
      goto yy817;
    goto yy805;
  yy821:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy805;
    if (yych <= 0x8F)
      goto yy817;
    goto yy805;
  yy822:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy822;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy805;
        if (yych >= 0x0E)
          goto yy805;
      } else {
        if (yych <= 0xDF)
          goto yy826;
        if (yych <= 0xE0)
          goto yy827;
        goto yy828;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy829;
        if (yych <= 0xEF)
          goto yy828;
        goto yy830;
      } else {
        if (yych <= 0xF3)
          goto yy831;
        if (yych <= 0xF4)
          goto yy832;
        goto yy805;
      }
    }
  yy824:
    ++p;
    p = marker;
    { return (bufsize_t)(p - start); }
  yy826:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy805;
    if (yych <= 0xBF)
      goto yy822;
    goto yy805;
  yy827:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy805;
    if (yych <= 0xBF)
      goto yy826;
    goto yy805;
  yy828:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy805;
    if (yych <= 0xBF)
      goto yy826;
    goto yy805;
  yy829:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy805;
    if (yych <= 0x9F)
      goto yy826;
    goto yy805;
  yy830:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy805;
    if (yych <= 0xBF)
      goto yy828;
    goto yy805;
  yy831:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy805;
    if (yych <= 0xBF)
      goto yy828;
    goto yy805;
  yy832:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy805;
    if (yych <= 0x8F)
      goto yy828;
    goto yy805;
  }
}

// Scan a closing code fence with length at least len.
bufsize_t _scan_close_code_fence(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0, 0, 0, 0, 0, 0, 0, 0, 0,  128, 0,   0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,  0,   128, 0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,  0,   0,   0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,  0,   0,   0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 32, 0,   0,   0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,  0,   0,   0, 0, 0, 0, 0, 64, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,  0,   0,   0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,  0,   0,   0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,  0,   0,   0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,  0,   0,   0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,  0,   0,   0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,  0,   0,   0, 0, 0,
    };
    yych = *p;
    if (yych == '`')
      goto yy837;
    if (yych == '~')
      goto yy838;
    ++p;
  yy836 : { return 0; }
  yy837:
    yych = *(marker = ++p);
    if (yych == '`')
      goto yy839;
    goto yy836;
  yy838:
    yych = *(marker = ++p);
    if (yych == '~')
      goto yy841;
    goto yy836;
  yy839:
    yych = *++p;
    if (yybm[0 + yych] & 32) {
      goto yy842;
    }
  yy840:
    p = marker;
    goto yy836;
  yy841:
    yych = *++p;
    if (yybm[0 + yych] & 64) {
      goto yy844;
    }
    goto yy840;
  yy842:
    yych = *++p;
    if (yybm[0 + yych] & 32) {
      goto yy842;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy840;
      if (yych <= '\t') {
        marker = p;
        goto yy846;
      }
      if (yych <= '\n') {
        marker = p;
        goto yy848;
      }
      goto yy840;
    } else {
      if (yych <= '\r') {
        marker = p;
        goto yy848;
      }
      if (yych == ' ') {
        marker = p;
        goto yy846;
      }
      goto yy840;
    }
  yy844:
    yych = *++p;
    if (yybm[0 + yych] & 64) {
      goto yy844;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy840;
      if (yych <= '\t') {
        marker = p;
        goto yy850;
      }
      if (yych <= '\n') {
        marker = p;
        goto yy852;
      }
      goto yy840;
    } else {
      if (yych <= '\r') {
        marker = p;
        goto yy852;
      }
      if (yych == ' ') {
        marker = p;
        goto yy850;
      }
      goto yy840;
    }
  yy846:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy846;
    }
    if (yych <= 0x08)
      goto yy840;
    if (yych <= '\n')
      goto yy848;
    if (yych != '\r')
      goto yy840;
  yy848:
    ++p;
    p = marker;
    { return (bufsize_t)(p - start); }
  yy850:
    yych = *++p;
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy840;
      if (yych <= '\t')
        goto yy850;
      if (yych >= '\v')
        goto yy840;
    } else {
      if (yych <= '\r')
        goto yy852;
      if (yych == ' ')
        goto yy850;
      goto yy840;
    }
  yy852:
    ++p;
    p = marker;
    { return (bufsize_t)(p - start); }
  }
}

// Scans an entity.
// Returns number of chars matched.
bufsize_t _scan_entity(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    yych = *p;
    if (yych == '&')
      goto yy858;
    ++p;
  yy857 : { return 0; }
  yy858:
    yych = *(marker = ++p);
    if (yych <= '@') {
      if (yych != '#')
        goto yy857;
    } else {
      if (yych <= 'Z')
        goto yy861;
      if (yych <= '`')
        goto yy857;
      if (yych <= 'z')
        goto yy861;
      goto yy857;
    }
    yych = *++p;
    if (yych <= 'W') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy862;
    } else {
      if (yych <= 'X')
        goto yy863;
      if (yych == 'x')
        goto yy863;
    }
  yy860:
    p = marker;
    goto yy857;
  yy861:
    yych = *++p;
    if (yych <= '@') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy864;
      goto yy860;
    } else {
      if (yych <= 'Z')
        goto yy864;
      if (yych <= '`')
        goto yy860;
      if (yych <= 'z')
        goto yy864;
      goto yy860;
    }
  yy862:
    yych = *++p;
    if (yych <= '/')
      goto yy860;
    if (yych <= '9')
      goto yy865;
    if (yych == ';')
      goto yy866;
    goto yy860;
  yy863:
    yych = *++p;
    if (yych <= '@') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy868;
      goto yy860;
    } else {
      if (yych <= 'F')
        goto yy868;
      if (yych <= '`')
        goto yy860;
      if (yych <= 'f')
        goto yy868;
      goto yy860;
    }
  yy864:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy869;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
        goto yy869;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych <= 'z')
          goto yy869;
        goto yy860;
      }
    }
  yy865:
    yych = *++p;
    if (yych <= '/')
      goto yy860;
    if (yych <= '9')
      goto yy870;
    if (yych != ';')
      goto yy860;
  yy866:
    ++p;
    { return (bufsize_t)(p - start); }
  yy868:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy871;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'F') {
        if (yych <= '@')
          goto yy860;
        goto yy871;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych <= 'f')
          goto yy871;
        goto yy860;
      }
    }
  yy869:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy872;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
        goto yy872;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych <= 'z')
          goto yy872;
        goto yy860;
      }
    }
  yy870:
    yych = *++p;
    if (yych <= '/')
      goto yy860;
    if (yych <= '9')
      goto yy873;
    if (yych == ';')
      goto yy866;
    goto yy860;
  yy871:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy874;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'F') {
        if (yych <= '@')
          goto yy860;
        goto yy874;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych <= 'f')
          goto yy874;
        goto yy860;
      }
    }
  yy872:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy875;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
        goto yy875;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych <= 'z')
          goto yy875;
        goto yy860;
      }
    }
  yy873:
    yych = *++p;
    if (yych <= '/')
      goto yy860;
    if (yych <= '9')
      goto yy876;
    if (yych == ';')
      goto yy866;
    goto yy860;
  yy874:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy877;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'F') {
        if (yych <= '@')
          goto yy860;
        goto yy877;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych <= 'f')
          goto yy877;
        goto yy860;
      }
    }
  yy875:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy878;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
        goto yy878;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych <= 'z')
          goto yy878;
        goto yy860;
      }
    }
  yy876:
    yych = *++p;
    if (yych <= '/')
      goto yy860;
    if (yych <= '9')
      goto yy879;
    if (yych == ';')
      goto yy866;
    goto yy860;
  yy877:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy880;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'F') {
        if (yych <= '@')
          goto yy860;
        goto yy880;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych <= 'f')
          goto yy880;
        goto yy860;
      }
    }
  yy878:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy881;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
        goto yy881;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych <= 'z')
          goto yy881;
        goto yy860;
      }
    }
  yy879:
    yych = *++p;
    if (yych <= '/')
      goto yy860;
    if (yych <= '9')
      goto yy882;
    if (yych == ';')
      goto yy866;
    goto yy860;
  yy880:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy882;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'F') {
        if (yych <= '@')
          goto yy860;
        goto yy882;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych <= 'f')
          goto yy882;
        goto yy860;
      }
    }
  yy881:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy883;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
        goto yy883;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych <= 'z')
          goto yy883;
        goto yy860;
      }
    }
  yy882:
    yych = *++p;
    if (yych == ';')
      goto yy866;
    goto yy860;
  yy883:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy884;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy884:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy885;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy885:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy886;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy886:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy887;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy887:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy888;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy888:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy889;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy889:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy890;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy890:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy891;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy891:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy892;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy892:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy893;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy893:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy894;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy894:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy895;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy895:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy896;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy896:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy897;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy897:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy898;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy898:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy899;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy899:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy900;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy900:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy901;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy901:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy902;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy902:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy903;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy903:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy904;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy904:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy905;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy905:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy906;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych >= '{')
          goto yy860;
      }
    }
  yy906:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy860;
      if (yych <= '9')
        goto yy882;
      if (yych <= ':')
        goto yy860;
      goto yy866;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy860;
        goto yy882;
      } else {
        if (yych <= '`')
          goto yy860;
        if (yych <= 'z')
          goto yy882;
        goto yy860;
      }
    }
  }
}

// Returns positive value if a URL begins in a way that is potentially
// dangerous, with javascript:, vbscript:, file:, or data:, otherwise 0.
bufsize_t _scan_dangerous_url(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    yych = *p;
    if (yych <= 'V') {
      if (yych <= 'F') {
        if (yych == 'D')
          goto yy911;
        if (yych >= 'F')
          goto yy912;
      } else {
        if (yych == 'J')
          goto yy913;
        if (yych >= 'V')
          goto yy914;
      }
    } else {
      if (yych <= 'f') {
        if (yych == 'd')
          goto yy911;
        if (yych >= 'f')
          goto yy912;
      } else {
        if (yych <= 'j') {
          if (yych >= 'j')
            goto yy913;
        } else {
          if (yych == 'v')
            goto yy914;
        }
      }
    }
    ++p;
  yy910 : { return 0; }
  yy911:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych == 'A')
      goto yy915;
    if (yych == 'a')
      goto yy915;
    goto yy910;
  yy912:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych == 'I')
      goto yy917;
    if (yych == 'i')
      goto yy917;
    goto yy910;
  yy913:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych == 'A')
      goto yy918;
    if (yych == 'a')
      goto yy918;
    goto yy910;
  yy914:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych == 'B')
      goto yy919;
    if (yych == 'b')
      goto yy919;
    goto yy910;
  yy915:
    yych = *++p;
    if (yych == 'T')
      goto yy920;
    if (yych == 't')
      goto yy920;
  yy916:
    p = marker;
    if (yyaccept == 0) {
      goto yy910;
    } else {
      goto yy928;
    }
  yy917:
    yych = *++p;
    if (yych == 'L')
      goto yy921;
    if (yych == 'l')
      goto yy921;
    goto yy916;
  yy918:
    yych = *++p;
    if (yych == 'V')
      goto yy922;
    if (yych == 'v')
      goto yy922;
    goto yy916;
  yy919:
    yych = *++p;
    if (yych == 'S')
      goto yy923;
    if (yych == 's')
      goto yy923;
    goto yy916;
  yy920:
    yych = *++p;
    if (yych == 'A')
      goto yy924;
    if (yych == 'a')
      goto yy924;
    goto yy916;
  yy921:
    yych = *++p;
    if (yych == 'E')
      goto yy925;
    if (yych == 'e')
      goto yy925;
    goto yy916;
  yy922:
    yych = *++p;
    if (yych == 'A')
      goto yy919;
    if (yych == 'a')
      goto yy919;
    goto yy916;
  yy923:
    yych = *++p;
    if (yych == 'C')
      goto yy926;
    if (yych == 'c')
      goto yy926;
    goto yy916;
  yy924:
    yych = *++p;
    if (yych == ':')
      goto yy927;
    goto yy916;
  yy925:
    yych = *++p;
    if (yych == ':')
      goto yy929;
    goto yy916;
  yy926:
    yych = *++p;
    if (yych == 'R')
      goto yy930;
    if (yych == 'r')
      goto yy930;
    goto yy916;
  yy927:
    yyaccept = 1;
    yych = *(marker = ++p);
    if (yych == 'I')
      goto yy931;
    if (yych == 'i')
      goto yy931;
  yy928 : { return (bufsize_t)(p - start); }
  yy929:
    ++p;
    goto yy928;
  yy930:
    yych = *++p;
    if (yych == 'I')
      goto yy932;
    if (yych == 'i')
      goto yy932;
    goto yy916;
  yy931:
    yych = *++p;
    if (yych == 'M')
      goto yy933;
    if (yych == 'm')
      goto yy933;
    goto yy916;
  yy932:
    yych = *++p;
    if (yych == 'P')
      goto yy934;
    if (yych == 'p')
      goto yy934;
    goto yy916;
  yy933:
    yych = *++p;
    if (yych == 'A')
      goto yy935;
    if (yych == 'a')
      goto yy935;
    goto yy916;
  yy934:
    yych = *++p;
    if (yych == 'T')
      goto yy925;
    if (yych == 't')
      goto yy925;
    goto yy916;
  yy935:
    yych = *++p;
    if (yych == 'G')
      goto yy936;
    if (yych != 'g')
      goto yy916;
  yy936:
    yych = *++p;
    if (yych == 'E')
      goto yy937;
    if (yych != 'e')
      goto yy916;
  yy937:
    yych = *++p;
    if (yych != '/')
      goto yy916;
    yych = *++p;
    if (yych <= 'W') {
      if (yych <= 'J') {
        if (yych == 'G')
          goto yy939;
        if (yych <= 'I')
          goto yy916;
        goto yy940;
      } else {
        if (yych == 'P')
          goto yy941;
        if (yych <= 'V')
          goto yy916;
        goto yy942;
      }
    } else {
      if (yych <= 'j') {
        if (yych == 'g')
          goto yy939;
        if (yych <= 'i')
          goto yy916;
        goto yy940;
      } else {
        if (yych <= 'p') {
          if (yych <= 'o')
            goto yy916;
          goto yy941;
        } else {
          if (yych == 'w')
            goto yy942;
          goto yy916;
        }
      }
    }
  yy939:
    yych = *++p;
    if (yych == 'I')
      goto yy943;
    if (yych == 'i')
      goto yy943;
    goto yy916;
  yy940:
    yych = *++p;
    if (yych == 'P')
      goto yy944;
    if (yych == 'p')
      goto yy944;
    goto yy916;
  yy941:
    yych = *++p;
    if (yych == 'N')
      goto yy945;
    if (yych == 'n')
      goto yy945;
    goto yy916;
  yy942:
    yych = *++p;
    if (yych == 'E')
      goto yy946;
    if (yych == 'e')
      goto yy946;
    goto yy916;
  yy943:
    yych = *++p;
    if (yych == 'F')
      goto yy947;
    if (yych == 'f')
      goto yy947;
    goto yy916;
  yy944:
    yych = *++p;
    if (yych == 'E')
      goto yy945;
    if (yych != 'e')
      goto yy916;
  yy945:
    yych = *++p;
    if (yych == 'G')
      goto yy947;
    if (yych == 'g')
      goto yy947;
    goto yy916;
  yy946:
    yych = *++p;
    if (yych == 'B')
      goto yy949;
    if (yych == 'b')
      goto yy949;
    goto yy916;
  yy947:
    ++p;
    { return 0; }
  yy949:
    yych = *++p;
    if (yych == 'P')
      goto yy947;
    if (yych == 'p')
      goto yy947;
    goto yy916;
  }
}
